<?php
/**
 * classes/ibit_Action_EvaluationActivation.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.1
 */

/**
 * Die Evaluationsaktivierung erzeugt Evaluationen aus Vorlagen.
 *
 * Diese Klasse bernimmt das Aktivieren von Evaluationen bzw. das Umsetzen von Vorlagen in konkrete Evaluationen.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.7
 */
class ibit_Action_EvaluationActivation
{
	/**
	 * Referenz auf die Templateklasse
	 * @var object $template
	 */
	var $template;

	/**
	 * Referenz auf das aufrufende Objekt
	 * @var objekt $parent
	 */
	var $parent;

	/**
	 * Konstruktor der Klasse.
	 * @param object $parent Referenz auf das aufrufende Objekt
	 */
	function ibit_Action_EvaluationActivation( $parent )
	{
		$this->template =& $GLOBALS['templatelite'];
		$this->parent = $parent;
	}

	/**
	 * Zeigt das Men zur Aktivierung an.
	 * @uses ibit_EvaluationTemplate::getTemplatesInfo()
	 * @uses ibit_Helper::getInstituteObjects()
	 * @uses ibit_Helper::getSemester()
	 */
	function show()
	{
		$template_infos = ibit_EvaluationTemplate::getTemplatesInfo( true );

		$tmp_institute = ibit_Helper::getInstituteObjects();

		$institute = Array();
		foreach ( $tmp_institute as $tmp_institut )
		{
			$institut = Array();
			$institut['id'] = $tmp_institut->id;
			$institut['name'] = $tmp_institut->name;
			$institut['children'] = Array();

			$children = $tmp_institut->childinstitutes;
			foreach ( $children as $child )
			{
				$sub_institut = Array();
				$sub_institut['id'] = $child->id;
				$sub_institut['name'] = $child->name;

				array_push( $institut['children'], $sub_institut );
			}
			array_push( $institute, $institut );
		}

		$this->template->assign( 'template_infos', $template_infos );
		$this->template->assign( 'semester_data', ibit_Helper::getSemester() );
		$this->template->assign( 'institute_data', $institute );
		$this->template->assign( 'link_accept', $this->parent->base_link.'&command=activate' );
		$this->template->assign( 'link_cancel', $this->parent->parent_link );
		$this->template->assign( 'link_preview', $this->parent->parent_link.'&section=templates&function=preview' );

		$this->template->display( 'admin.evaluation_activation.tpl' );
	}

	/**
	 * Aktiviert eine Vorlage.
	 * @uses ibit_Evaluation
	 * @uses ibit_Helper::checkNumber()
	 * @uses ibit_Helper::getSeminarsForInstitute()
	 * @uses ibit_Helper::getFacultyForInstitute()
	 * @uses ibit_Helper::protectTemplate()
	 * @uses ibit_Helper::getInstituteObject()
	 */
	function activate()
	{
		$error = Array();
		# Tag berprfen
		ibit_Helper::checkNumber( $_POST['start_day'], 1, 31, 'Start-Tag', $error );
		# Monat berprfen
		ibit_Helper::checkNumber( $_POST['start_month'], 1, 12, 'Start-Monat', $error );
		# Jahr berprfen
		ibit_Helper::checkNumber( $_POST['start_year'], 2000, null, 'Start-Jahr', $error );
		# Laufzeit berprfen
		ibit_Helper::checkNumber( $_POST['duration_days'], 1, null, 'Laufzeit', $error );
		# Template-Id berprfen
		if ( empty( $_POST['activation_template_id'] ) )
		{
			array_push( $error, 'Bitte Evaluationsvorlage whlen' );
		}
		# Semester-Id berprfen
		if ( empty( $_POST['semester_id'] ) )
		{
			array_push( $error, 'Bitte gltiges Semester whlen' );
		}
		# Institut-Ids berprfen
		if ( empty( $_POST['institute'] ) )
		{
			array_push( $error, 'Bitte mindestens ein Institut auswhlen' );
		}
		#Veranstaltungsart berprfen
		if ( empty( $_POST['coursetype'] ) )
		{
			array_push( $error, 'Bitte mindestens ein Veranstaltungsart auswhlen' );
		}

		if ( !empty($error) )
		{
			foreach ($error as $e)
			{
				$this->template->append( 'messages_errors', $e );
			}
			$this->show();
			return;
		}

		$start_time = mktime( 0, 0, 0, $_POST['start_month'], $_POST['start_day'], $_POST['start_year'] );
		$end_time = $start_time + $_POST['duration_days'] * 24 * 60 * 60 - 1;
		$eval_template_id = $_POST['activation_template_id'];
		$semester_id = $_POST['semester_id'];
		$coursetypes = $_POST['coursetype'];


		$institute = Array();
		foreach ( $_POST['institute'] as $institute_id )
		{
			$inst = ibit_Helper::getInstituteObject( $institute_id );
			array_push( $institute, $inst->getId() );

			$children = $inst->getAllChildInstitutes();
			foreach ( $children as $child )
			{
				array_push( $institute, $child->getId() );
			}
		}

		// Kurse fr ausgewhlte Fakultten und Institute laden
		$institute = array_unique( $institute );
		$courses = Array();
		foreach ( $institute as $institute_id )
		{
			$tmp_courses = ibit_Helper::getSeminarsForInstitute( $institute_id, $semester_id );
			$faculty_id = ibit_Helper::getFacultyForInstitute( $institute_id );

			foreach ($tmp_courses as $course)
			{
				if ( in_array( $course['typ'], $coursetypes) || ( in_array( 'other', $coursetypes) && $course['typ'] != 1 && $course['typ'] != 2 && $course['typ'] != 3) )
				{
					$course['institute_id'] = $institute_id;
					$course['faculty_id'] = $faculty_id;
					array_push( $courses, $course );
				}
			}
		}

		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );
		$sql_insert_tutor = 'INSERT INTO `ibit_evaluation_user` ( `evaluation_id` , `user_id` , `timestamp` , `hidden` ) VALUES (?, ?, NOW(), 1)';


		// Evals erstellen und in die DB speichern
		$course_done = Array();
		$entries = 0;
		foreach ($courses as $course)
		{
			if ( in_array( $course['id'], $course_done) )
			{
				continue;
			}
			array_push( $course_done, $course['id'] );

			$evaluation = new ibit_Evaluation();
			$evaluation->setTemplateId( $eval_template_id );
			$evaluation->setSeminarId( $course['id'] );
			$evaluation->setInstitutId( $course['institute_id'] );
			$evaluation->setFakultaetId( $course['faculty_id'] );
			$evaluation->setStatus( 1 );
			$evaluation->setConfirmed( 0 );
			$evaluation->setSemesterId( $semester_id );
			$evaluation->setStartDate( $start_time );
			$evaluation->setStopDate( $end_time );
			$evaluation->setCreateAuthorId( $_SESSION['auth']->auth['uid'] );
			$evaluation->setChangeAuthorId( $_SESSION['auth']->auth['uid'] );
			$evaluation->save();

			// Insert tutors into user table
			$tutor_ids = ibit_EvaluationSeminar::getTutorsForSeminar($course['id']);
			foreach ($tutor_ids as $tutor_id)
			{
				$conn->Execute($sql_insert_tutor, Array($evaluation->getId(), $tutor_id));
			}

			$entries += 1;
		}
		$conn->Close();

		//Das Eval-Template gegen Vernderungen sperren, da in Benutzung.
		ibit_Helper::protectTemplate( $eval_template_id );

		$this->template->append( 'messages_success', 'Die Evaluation wurde erfolgreich in <strong>'.$entries.'</strong> Veranstaltungen eingetragen' );
		$this->parent->evaluation_administration();
	}
}
?>