<?php
/**
 * classes/ibit_Action_EvaluationActivationSeminar.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.1
 */

/**
 * Die Evaluationsaktivierung erzeugt eine Evaluation fr ein einzelnes Seminar aus einer Vorlagen.
 *
 * Diese Klasse bernimmt das Aktivieren von Evaluationen bzw. das Umsetzen von Vorlagen in konkrete Evaluationen fr einzelne Seminare.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.1
 */
class ibit_Action_EvaluationActivationSeminar
{
	/**
	 * Referenz auf die Templateklasse
	 * @var object $template
	 */
	var $template;

	/**
	 * Referenz auf das aufrufende Objekt
	 * @var objekt $parent
	 */
	var $parent;

	/**
	 * Konstruktor der Klasse.
	 * @param object $parent Referenz auf das aufrufende Objekt
	 */
	function ibit_Action_EvaluationActivationSeminar( $parent )
	{
		$this->template =& $GLOBALS['templatelite'];
		$this->parent = $parent;
	}

	/**
	 * Zeigt das Men zur Suche an.
	 * @uses ibit_Helper::getSemester()
	 * @uses ibit_EvaluationSeminar::searchSeminarByNameAndSemester();
	 */
	function show()
	{
		$this->template->assign( 'semester_data', ibit_Helper::getSemester() );
		$this->template->assign( 'link_accept', $this->parent->base_link.'&command=searched' );
		$this->template->assign( 'link_cancel', $this->parent->parent_link );
		$this->template->assign( 'link_search', $this->parent->base_link );

		if ( !empty( $_POST ) )
		{
			if ( ( strlen( $_POST['name'] ) < 3 ) and ( strlen( $_POST['number'] ) < 3 ) )
			{
				 $this->template->append( 'messages_errors', 'Der Suchbegriff muss mindestens 3 Zeichen lang sein' );
			}
			else
			{
				$seminar_data = ibit_EvaluationSeminar::searchSeminarByNameAndSemester( $_POST['name'], $_POST['number'], $_POST['semester_id'] );
				$this->template->assign( 'seminar_data', $seminar_data );
				$this->template->assign( 'semester_id', $_POST['semester_id'] );
			}
		}

		$this->template->display( 'admin.evaluation_activation_seminar_search.tpl' );
	}

	/**
	 * Zeigt das Men zum Aktivieren an.
	 * @uses ibit_EvaluationSeminar::getSeminarData()
	 * @uses ibit_EvaluationTemplate::getTemplatesInfo()
	 * @uses ibit_Helper::getSemester()
	 */
	function searched()
	{
		if ( empty( $_POST['seminar_id'] ) )
		{
			$this->template->append( 'messags_errors', 'Bitte ein gltiges Semimar auswhlen' );
			$this->show();
			return;
		}
		$template_infos = ibit_EvaluationTemplate::getTemplatesInfo( true );

		$this->template->assign( 'semester_id', $_POST['semester_id'] );
		$this->template->assign( 'seminar_data', array_pop( ibit_EvaluationSeminar::getSeminarData( $_POST['seminar_id'] ) ) );
		//print_r(ibit_EvaluationSeminar::getSeminarData( $_POST['seminar_id']));
		$this->template->assign( 'template_infos', $template_infos );
		//$this->template->assign( 'semester_data', ibit_Helper::getSemester() );
		$this->template->assign( 'link_accept', $this->parent->base_link.'&command=activate' );
		$this->template->assign( 'link_cancel', $this->parent->parent_link );
		$this->template->assign( 'link_preview', $this->parent->parent_link.'&section=templates&function=preview' );

		$this->template->display( 'admin.evaluation_activation_seminar.tpl' );
	}

	/**
	 * Aktiviert eine Vorlage fr ein Seminar.
	 * @uses ibit_Evaluation
	 * @uses ibit_DatabaseConnection
	 * @uses ibit_Helper::checkNumber()
	 * @uses ibit_EvaluationSeminar::getSeminarData()
	 * @uses ibit_Helper::protectTemplate()
	 */
	function activate()
	{
		$error = Array();
		# Tag berprfen
		ibit_Helper::checkNumber( $_POST['start_day'], 1, 31, 'Start-Tag', $error );
		# Monat berprfen
		ibit_Helper::checkNumber( $_POST['start_month'], 1, 12, 'Start-Monat', $error );
		# Jahr berprfen
		ibit_Helper::checkNumber( $_POST['start_year'], 2000, null, 'Start-Jahr', $error );
		# Laufzeit berprfen
		ibit_Helper::checkNumber( $_POST['duration_days'], 1, null, 'Laufzeit', $error );
		# Template-Id berprfen
		if ( empty( $_POST['activation_template_id'] ) )
		{
			array_push( $error, 'Bitte Evaluationsvorlage whlen' );
		}
		# Semester-Id berprfen
		if ( empty( $_POST['semester_id'] ) )
		{
			array_push( $error, 'Bitte gltiges Semester whlen' );
		}
		# Institut-Ids berprfen
		if ( empty( $_POST['seminar_id'] ) )
		{
			array_push( $error, 'Bitte ein gltiges Seminar auswhlen' );
		}

		if ( !empty($error) )
		{
			foreach ($error as $e)
			{
				$this->template->append( 'messages_errors', $e );
			}
			$this->show();
			return;
		}

		$start_time = mktime( 0, 0, 0, $_POST['start_month'], $_POST['start_day'], $_POST['start_year'] );
		$end_time = $start_time + $_POST['duration_days'] * 24 * 60 * 60 - 1;
		$eval_template_id = $_POST['activation_template_id'];
		$semester_id = $_POST['semester_id'];
		$seminar_id = $_POST['seminar_id'];

		$seminar_info = array_pop( ibit_EvaluationSeminar::getSeminarData( $seminar_id ) );

		$evaluation = new ibit_Evaluation();
		$evaluation->setTemplateId( $eval_template_id );
		$evaluation->setSeminarId( $_POST['seminar_id'] );
		$evaluation->setInstitutId( $seminar_info['Institut_id'] );
		$evaluation->setFakultaetId( $seminar_info['Fakultaets_id'] );
		$evaluation->setStatus( 1 );
		$evaluation->setConfirmed( 0 );
		$evaluation->setSemesterId( $semester_id );
		$evaluation->setStartDate( $start_time );
		$evaluation->setStopDate( $end_time );
		$evaluation->setCreateAuthorId( $_SESSION['auth']->auth['uid'] );
		$evaluation->setChangeAuthorId( $_SESSION['auth']->auth['uid'] );
		$evaluation->save();

		ibit_Helper::protectTemplate( $eval_template_id );

		// Insert tutors into user table
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );
		$sql_insert_tutor = 'INSERT INTO ibit_evaluation_user (evaluation_id, user_id, timestamp, hidden) VALUES (?, ?, NOW(), 1)';

		$tutor_ids = ibit_EvaluationSeminar::getTutorsForSeminar( $_POST['seminar_id'] );
		foreach ( $tutor_ids as $tutor_id )
		{
			$conn->Execute($sql_insert_tutor, Array($evaluation->getId(), $tutor_id));
		}
		$conn->Close();

		$this->template->append( 'messages_success', 'Die Evaluation fr das Seminar wurde erfolgreich eingetragen' );
		$this->parent->templates_index();
	}
}
?>