<?php
/**
 * classes/ibit_Action_EvaluationAdministration.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.5
 */

/**
 * Die Klasse zur Evaluationsverwaltung
 *
 * Diese Klasse bernimmt die Verwaltung der Evaluationen. Es werden Funktionen zum Anzeigen, Bearbeiten und Lschen von Evaluationen
 * bereitgestellt.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.7
 */
class ibit_Action_EvaluationAdministration
{
	/**
	 * Referenz auf das aufrufende Objekt
	 * @var object $parent
	 */
	var $parent;

	/**
	 * Referenz auf die Templateklasse
	 * @var object $templatelite
	 */
	var $templatelite;

	/**
	 * Der Konstruktor der Klasse.
	 * @param object $parent Referenz auf das aufrufende Objekt
	 */
	function ibit_Action_EvaluationAdministration( $parent )
	{
		$this->templatelite =& $GLOBALS['templatelite'];
		$this->parent = $parent;

		$this->save_display_params();
	}

	/**
	 * Zeigt den Header der Seite an.
	 * @param string $command Aktuelles Kommando
	 * @uses ibit_Helper::getSemester()
	 */
	function displayHeader( $command )
	{
		$params = '';
		if ( !empty( $_REQUEST['faculty_id'] ) )
		{
			$params .= '&faculty_id='.$_REQUEST['faculty_id'];
		}
		if ( !empty( $_REQUEST['institute_id'] ) )
		{
			$params .= '&institute_id='.$_REQUEST['institute_id'];
			$this->templatelite->assign( 'institute_view', true );
		}
		if (!empty( $_REQUEST['skip'] ) )
		{
			$params .= '&skip='.$_REQUEST['skip'];
		}

		$this->templatelite->assign( 'link_evaluation_customize', $this->parent->base_link.'&command='.$command.$params );
		$this->templatelite->assign( 'semester_data', ibit_Helper::getSemester() );
		$this->templatelite->display( 'admin.evaluation_administration.header.tpl' );
	}

	/**
	 * Speichert die im Request bergebenen Darstellungsparameter.
	 * @uses ibit_Helper::getSemester()
	 */
	function save_display_params()
	{
		if ( !isset( $_SESSION['show_expired'] ) )
		{
			$_SESSION['show_expired'] = 1;
			$_SESSION['show_current'] = 1;
			$_SESSION['show_future'] = 1;
			$_SESSION['evaladmin_maxrows'] = 25;
			$_SESSION['semester_id'] = -1;
			$semester_data = ibit_Helper::getSemester();
			foreach ($semester_data as $semester)
			{
				if ($semester['currentsemester'])
				{
					$_SESSION['semester_id'] = $semester['id'];
				}
			}
		}

		if ( !empty( $_GET['show_expired'] ) )
		{
			$_SESSION['show_expired'] = $_GET['show_expired'];
		}
		if ( !empty( $_GET['show_current'] ) )
		{
			$_SESSION['show_current'] = $_GET['show_current'];
		}
		if ( !empty( $_GET['show_future'] ) )
		{
			$_SESSION['show_future'] = $_GET['show_future'];
		}

		if ( empty( $_POST['semester_id'] ) )
		{
			return;
		}

		$_SESSION['semester_id'] = $_POST['semester_id'];
		$_SESSION['show_expired'] = empty( $_POST['show_expired'] ) ? 0 : 1;
		$_SESSION['show_current'] = empty( $_POST['show_current'] ) ? 0 : 1;
		$_SESSION['show_future'] = empty( $_POST['show_future'] ) ? 0 : 1;
		$_SESSION['show_notempty'] = empty( $_POST['show_notempty'] ) ? 0 : 1;
		$_SESSION['show_notguilty'] = empty( $_POST['show_notguilty'] ) ? 0 : 1;
		$_SESSION['evaladmin_maxrows'] = empty( $_POST['evaladmin_maxrows'] ) ? 40 : $_POST['evaladmin_maxrows'];
	}

	/**
	 * Lscht alle Evaluationen der bergebenen Institute in Abhngigkeit der Sichtbarkeitseinstellungen (abgelaufen, laufend, zuknftig).
	 * @param mixed $institute_id Id des Instituts
	 * @return int Anzahl der gelschten Evaluationen
	 * @uses ibit_Evaluation::getExpiredEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getCurrentEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getFutureEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::delete()
	 */
	function deleteEvaluationsByInstituteId( $institute_ids )
	{
		$eval_count = 0;

		$evaluation_data = Array();
		if ( $_SESSION['show_expired'] )
		{
			$evaluation_data = array_merge( $evaluation_data, ibit_Evaluation::getExpiredEvaluationsByInstituteId( $institute_ids, $foo=null, $bar=null, $count, $_SESSION['semester_id'] ) );
			$eval_count += $count;
		}
		if ( $_SESSION['show_current'] )
		{
			$evaluation_data = array_merge( $evaluation_data, ibit_Evaluation::getCurrentEvaluationsByInstituteId( $institute_ids, $foo=null, $bar=null, $count, $_SESSION['semester_id'] ) );
			$eval_count += $count;
		}
		if ( $_SESSION['show_future'] )
		{
			$evaluation_data = array_merge( $evaluation_data, ibit_Evaluation::getFutureEvaluationsByInstituteId( $institute_ids, $foo=null, $bar=null, $count, $_SESSION['semester_id'] ) );
			$eval_count += $count;
		}

		$ids = Array();
		foreach ( $evaluation_data as $evaluation )
		{
			array_push( $ids, $evaluation['evaluation_id'] );
		}
		ibit_Evaluation::delete( $ids );

		return $eval_count;
	}

	/**
	 * Zeigt die Details und das Formular zum Bearbeiten einer Evaluation an.
	 * @param int $evaluation_id Id der Evaluation
	 * @uses ibit_Evaluation
	 * @uses ibit_Action_Summary
	 */
	function evaluation_details( $evaluation_id, $fakview=false )
	{
		$evaluation = new ibit_Evaluation( $evaluation_id );

		$this->templatelite->assign( 'link_confirm', $this->parent->base_link.'&command=edit_evaluation&evaluation_id='.$evaluation_id.'&skip='.$_REQUEST['skip'].'&institute_id='.$evaluation->getInstitutId() );
		$this->templatelite->assign( 'link_cancel', $this->parent->base_link.'&command=show_institute&institute_id='.$evaluation->getInstitutId().'&skip='.$_REQUEST['skip'] );
		$this->templatelite->assign( 'evaluation', $evaluation->flattenToArray() );

		if ( !$fakview)
		{
			$this->templatelite->display( 'admin.evaluation_administration.edit_evaluation.tpl' );
		}

		if ( $evaluation->getStopDate() < time() and $evaluation->getNumberOfParticipants() > $GLOBALS['ibit_eval_minusers'] )
		{
			$summary = new ibit_Action_Summary( $this->parent->parent, $evaluation_id );
			$summary->show();
		}
		elseif($evaluation->getStopDate() > time() and $evaluation->getNumberOfParticipants() > $GLOBALS['ibit_eval_minusers'])
		{
			$this->templatelite->append( 'messages_error', 'Die Auswertung kann nicht angezeigt werden, da zu wenig Teinehmer vorhanden sind.' );
		}
	}


	/**
	 * Speichert die nderungen an einer Evaluation.
	 * @param int $evaluation_id Id der Evaluation
	 * @uses ibit_Evaluation
	 */
	function edit_evaluation( $evaluation_id )
	{
		$evaluation = new ibit_Evaluation( $evaluation_id );

		$error = Array();
		ibit_Helper::checkNumber( $_POST['start_day'], 1, 31, 'Start-Tag', $error );
		ibit_Helper::checkNumber( $_POST['start_month'], 1, 12, 'Start-Monat', $error );
		ibit_Helper::checkNumber( $_POST['start_year'], 2000, null, 'Start-Jahr', $error );
		ibit_Helper::checkNumber( $_POST['stop_day'], 1, 31, 'End-Tag', $error );
		ibit_Helper::checkNumber( $_POST['stop_month'], 1, 12, 'End-Monat', $error );
		ibit_Helper::checkNumber( $_POST['stop_year'], 2000, null, 'End-Jahr', $error );

		if ( empty($error) )
		{
			$start_day = $_POST['start_day'];
			$start_month = $_POST['start_month'];
			$start_year = $_POST['start_year'];
			$start_time = mktime( 0, 0, 0, $start_month, $start_day, $start_year );

			$evaluation->setStartDate( $start_time );

			$stop_day = $_POST['stop_day'];
			$stop_month = $_POST['stop_month'];
			$stop_year = $_POST['stop_year'];
			$stop_time = mktime( 23, 59, 59, $stop_month, $stop_day, $stop_year );

			$evaluation->setStopDate( $stop_time );

			$evaluation->save();

			$this->templatelite->append( 'messages_success', 'Evaluation wurde editiert' );
			$this->displayHeader( 'show_institute' );
			$this->show_institute( $evaluation->getInstitutId() );
		}
		else
		{
			$this->templatelite->assign( 'messages_errors', $error );
			$this->evaluation_details( $evaluation_id );
		}
	}

	/**
	 * Zeigt einen berblick aller Evaluationen gruppiert nach Fakultten an.
	 * @uses ibit_Evaluation::getExpiredEvaluationsFacultyOverview()
	 * @uses ibit_Evaluation::getCurrentEvaluationsFacultyOverview()
	 * @uses ibit_Evaluation::getFutureEvaluationsFacultyOverview()
	 */
	function show_overview()
	{
		$evaluations = Array();
		$evaluation_count = Array('expired'=>0, 'current'=>0, 'future'=>0);
		if ( $_SESSION['show_expired'] )
		{
			$evals = ibit_Evaluation::getExpiredEvaluationsFacultyOverview( $_SESSION['semester_id'] );
			foreach ( $evals as $eval )
			{
				if ( empty( $evaluations[ $eval['fakultaet_id'] ] ) )
				{
					$data = $eval;
					$data['expired_count'] = $eval['evaluation_count'];
					$data['current_count'] = 0;
					$data['future_count'] = 0;
					$evaluations[ $eval['fakultaet_id'] ] = $data;
				}
				else
				{
					$evaluations[ $eval['fakultaet_id'] ]['expired_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ]['seminar_count'] += $eval['seminar_count'];
					$evaluations[ $eval['fakultaet_id'] ]['seminar_members'] += $eval['seminar_members'];
					$evaluations[ $eval['fakultaet_id'] ]['institute_count'] += $eval['institute_count'];
					$evaluations[ $eval['fakultaet_id'] ]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ]['participants'] += $eval['participants'];
				}
				$evaluation_count['expired'] += $eval['evaluation_count'];
			}
		}
		if ( $_SESSION['show_current'] )
		{
			$evals = ibit_Evaluation::getCurrentEvaluationsFacultyOverview( $_SESSION['semester_id'] );
			foreach ( $evals as $eval )
			{
				if ( empty( $evaluations[ $eval['fakultaet_id'] ] ) )
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = $eval['evaluation_count'];
					$data['future_count'] = 0;
					$evaluations[ $eval['fakultaet_id'] ] = $data;
				}
				else
				{
					$evaluations[ $eval['fakultaet_id'] ]['current_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ]['seminar_count'] += $eval['seminar_count'];
					$evaluations[ $eval['fakultaet_id'] ]['seminar_members'] += $eval['seminar_members'];
					$evaluations[ $eval['fakultaet_id'] ]['institute_count'] += $eval['institute_count'];
					$evaluations[ $eval['fakultaet_id'] ]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ]['participants'] += $eval['participants'];
				}
				$evaluation_count['current'] += $eval['evaluation_count'];
			}
		}
		if ( $_SESSION['show_future'] )
		{
			$evals = ibit_Evaluation::getFutureEvaluationsFacultyOverview( $_SESSION['semester_id'] );
			foreach ( $evals as $eval )
			{
				if ( empty( $evaluations[ $eval['fakultaet_id'] ] ) )
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = 0;
					$data['future_count'] = $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ] = $data;
				}
				else
				{
					$evaluations[ $eval['fakultaet_id'] ]['future_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ]['seminar_count'] += $eval['seminar_count'];
					$evaluations[ $eval['fakultaet_id'] ]['seminar_members'] += $eval['seminar_members'];
					$evaluations[ $eval['fakultaet_id'] ]['institute_count'] += $eval['institute_count'];
					$evaluations[ $eval['fakultaet_id'] ]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['fakultaet_id'] ]['participants'] += $eval['participants'];
				}
				$evaluation_count['future'] += $eval['evaluation_count'];
			}
		}

		// Anzahl freigeschalteter Evals ausgeben
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );
		$sql = "SELECT COUNT( * ) AS evaluation_visibles FROM ibit_evaluation WHERE visible_date IS NOT NULL AND semester_id = ".$_SESSION['semester_id'];
		$vresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'visible_count', $vresult->fields['evaluation_visibles'] );

		// Anzahl kommentierter Evals ausgeben
		$sql = "SELECT COUNT( * ) AS evaluation_comments FROM ibit_evaluation WHERE comment IS NOT NULL AND semester_id = ".$_SESSION['semester_id'];
		$cresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'comments_count', $cresult->fields['evaluation_comments'] );

		// Anzahl gltiger Evals
		$sql = "SELECT COUNT( * ) AS guilty_count FROM (SELECT COUNT( u.evaluation_id ) AS count_guilty FROM ibit_evaluation_user AS u INNER JOIN ibit_evaluation AS e USING ( evaluation_id ) WHERE e.semester_id = ".$_SESSION['semester_id']." GROUP BY u.evaluation_id HAVING SUM( u.hidden <>1 ) > ".$GLOBALS['ibit_eval_minusers'].") AS temp";
		$cresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'guilty_count', $cresult->fields['guilty_count'] );

		foreach ( $evaluations as $faculty_id=>$faculty_data )
		{
			$evaluations[ $faculty_id ]['institute_total_count'] = ibit_Helper::getInstituteCountByFacultyId( $faculty_id );
			$evaluations[ $faculty_id ]['seminar_total_count'] = ibit_Helper::getSeminarCountByFacultyId( $faculty_id, $_SESSION['semester_id'] );
		}

		$this->templatelite->assign( 'evaluation_data', $evaluations );
		$evaluation_count['total'] = array_sum( $evaluation_count );
		$this->templatelite->assign( 'evaluation_count', $evaluation_count );
		$this->templatelite->assign( 'link_faculty_detail', $this->parent->base_link.'&command=show_faculty' );

		$this->templatelite->display( 'admin.evaluation_administration.over_view.tpl' );
	}

	/**
	 * Zeigt einen berblick aller Evaluationen einer Fakultt gruppiert nach Instituten an.
	 * @param string $faculty_id Id der Fakultt
	 * @uses ibit_Evaluation::getExpiredEvaluationsByFacultyId()
	 * @uses ibit_Evaluation::getCurrentEvaluationsByFacultyId()
	 * @uses ibit_Evaluation::getFutureEvaluationsByFacultyId()
	 */
	function show_faculty( $faculty_id, $fakview=false)
	{
		$evaluation_count = Array('expired'=>0, 'current'=>0, 'future'=>0);

		$evaluations = Array();
		if ( $_SESSION['show_expired'] )
		{
			$evals = ibit_Evaluation::getExpiredEvaluationsByFacultyId( $faculty_id, $_SESSION['semester_id'] );
			foreach ( $evals as $eval )
			{
				if ( empty( $evaluations[ $eval['institut_id'] ] ) )
				{
					$data = $eval;
					$data['expired_count'] = $eval['evaluation_count'];
					$data['current_count'] = 0;
					$data['future_count'] = 0;
					$evaluations[ $eval['institut_id'] ] = $data;
				}
				else
				{
					$evaluations[ $eval['institut_id'] ]['expired_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ]['seminar_count'] += $eval['seminar_count'];
					$evaluations[ $eval['institut_id'] ]['seminar_members'] += $eval['seminar_members'];
					$evaluations[ $eval['institut_id'] ]['participants'] += $eval['participants'];
				}
				$evaluation_count['expired'] += $eval['evaluation_count'];
			}
		}
		if ( $_SESSION['show_current'] )
		{
			$evals = ibit_Evaluation::getCurrentEvaluationsByFacultyId( $faculty_id, $_SESSION['semester_id'] );
			foreach ( $evals as $eval )
			{
				if ( empty( $evaluations[ $eval['institut_id'] ] ) )
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = $eval['evaluation_count'];
					$data['future_count'] = 0;
					$evaluations[ $eval['institut_id'] ] = $data;
				}
				else
				{
					$evaluations[ $eval['institut_id'] ]['current_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ]['seminar_count'] += $eval['seminar_count'];
					$evaluations[ $eval['institut_id'] ]['seminar_members'] += $eval['seminar_members'];
					$evaluations[ $eval['institut_id'] ]['participants'] += $eval['participants'];
				}
				$evaluation_count['current'] += $eval['evaluation_count'];
			}
		}
		if ( $_SESSION['show_future'] )
		{
			$evals = ibit_Evaluation::getFutureEvaluationsByFacultyId( $faculty_id, $_SESSION['semester_id'] );
			foreach ( $evals as $eval )
			{
				if ( empty( $evaluations[ $eval['institut_id'] ] ) )
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = 0;
					$data['future_count'] = $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ] = $data;
				}
				else
				{
					$evaluations[ $eval['institut_id'] ]['future_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[ $eval['institut_id'] ]['seminar_count'] += $eval['seminar_count'];
					$evaluations[ $eval['institut_id'] ]['seminar_members'] += $eval['seminar_members'];
					$evaluations[ $eval['institut_id'] ]['participants'] += $eval['participants'];
				}
				$evaluation_count['future'] += $eval['evaluation_count'];
			}
		}

		// Anzahl freigeschalteter Evals ausgeben
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );
		$sql = "SELECT COUNT( * ) AS evaluation_visibles FROM ibit_evaluation WHERE visible_date IS NOT NULL AND fakultaet_id = ".$faculty_id." AND semester_id = ".$_SESSION['semester_id'];
		$vresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'visible_count', $vresult->fields['evaluation_visibles'] );

		// Anzahl kommentierter Evals ausgeben
		$sql = "SELECT COUNT( * ) AS evaluation_comments FROM ibit_evaluation WHERE comment IS NOT NULL AND fakultaet_id = ".$faculty_id." AND semester_id = ".$_SESSION['semester_id'];
		$cresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'comments_count', $cresult->fields['evaluation_comments'] );

		// Anzahl gltiger Evals
		$sql = "SELECT COUNT( * ) AS guilty_count FROM (SELECT COUNT( u.evaluation_id ) AS count_guilty FROM ibit_evaluation_user AS u INNER JOIN ibit_evaluation AS e USING ( evaluation_id ) WHERE fakultaet_id = ".$faculty_id." AND e.semester_id = ".$_SESSION['semester_id']." GROUP BY u.evaluation_id HAVING SUM( u.hidden <>1 ) > ".$GLOBALS['ibit_eval_minusers'].") AS temp";
		$cresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'guilty_count', $cresult->fields['guilty_count'] );

		foreach ( $evaluations as $institute_id=>$institute_data )
		{
			$evaluations[ $institute_id ]['seminar_total_count'] = ibit_Helper::getSeminarCountByInstituteId( $institute_id, $_SESSION['semester_id'] );
		}

		$evaluation_count['total'] = array_sum( $evaluation_count );
		$this->templatelite->assign( 'evaluation_count', $evaluation_count );
		$this->templatelite->assign( 'evaluation_data', $evaluations );
		$this->templatelite->assign( 'link_institute_detail', $this->parent->base_link.'&command=show_institute' );
		$this->templatelite->assign( 'link_delete', $this->parent->base_link.'&command=show_faculty&faculty_id='.$faculty_id.'&action=delete_evaluations_by_institute_ids' );
		$this->templatelite->assign( 'link_back', $this->parent->base_link.'&command=show_faculties' );

		if ( $fakview )
		{
			$this->templatelite->display( 'fakadmin.faculty_view.tpl' );
		}
		else
		{
			$this->templatelite->display( 'admin.evaluation_administration.faculty_view.tpl' );
		}

	}

	/**
	 * Zeigt einen berblick aller Evaluationen eines Instituts an.
	 * @param string $institute_id Id des Instituts
	 * @uses ibit_Evaluation::getExpiredEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getCurrentEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getFutureEvaluationsByInstituteId()
	 */
	function show_institute( $institute_id, $fakview=false )
	{


		$skip = ( !empty( $_REQUEST['skip'] ) and ( $_SESSION['evaladmin_maxrows'] != -1 ) ) ? $_REQUEST['skip'] : 0;
		$limit = $_SESSION['evaladmin_maxrows'] == -1 ? 100000000 : $_SESSION['evaladmin_maxrows'];

		$tmp_skip = $skip;
		$tmp_limit = $limit;
		$total_count = 0;
		$count = 0;

		$evaluation_data = Array();
		if ( $_SESSION['show_expired'] )
		{
			$evaluation_temp_data = ibit_Evaluation::getExpiredEvaluationsByInstituteId( $institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id'] );
			$evaluation_data = array_merge( $evaluation_data,  $evaluation_temp_data );
			$total_count += $count;
		}
		if ( $_SESSION['show_current'] )
		{
			$evaluation_temp_data = ibit_Evaluation::getCurrentEvaluationsByInstituteId( $institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id'] );
			$evaluation_data = array_merge( $evaluation_data, $evaluation_temp_data	);
			$total_count += $count;
		}
		if ( $_SESSION['show_future'] )
		{
			$evaluation_temp_data = ibit_Evaluation::getFutureEvaluationsByInstituteId( $institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id'] );
			$evaluation_data = array_merge( $evaluation_data, $evaluation_temp_data	);
			$total_count += $count;
		}

		// Anzahl freigeschalteter Evals ausgeben
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );
		$sql = "SELECT COUNT( * ) AS evaluation_visibles FROM ibit_evaluation WHERE visible_date IS NOT NULL AND institut_id = ".$institute_id." AND semester_id = ".$_SESSION['semester_id'];
		$vresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'visible_count', $vresult->fields['evaluation_visibles'] );

		// Anzahl kommentierter Evals ausgeben
		$sql = "SELECT COUNT( * ) AS evaluation_comments FROM ibit_evaluation WHERE comment IS NOT NULL AND institut_id = ".$institute_id." AND semester_id = ".$_SESSION['semester_id'];
		$cresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'comments_count', $cresult->fields['evaluation_comments'] );

		// Anzahl gltiger Evals
		$sql = "SELECT COUNT( * ) AS guilty_count FROM (SELECT COUNT( u.evaluation_id ) AS count_guilty FROM ibit_evaluation_user AS u INNER JOIN ibit_evaluation AS e USING ( evaluation_id ) WHERE institut_id = ".$institute_id." AND e.semester_id = ".$_SESSION['semester_id']." GROUP BY u.evaluation_id HAVING SUM( u.hidden <>1 ) > ".$GLOBALS['ibit_eval_minusers'].") AS temp";
		$cresult = $conn->Execute( $sql );
		$this->templatelite->assign( 'guilty_count', $cresult->fields['guilty_count'] );

		if ( $total_count > 0 and $skip >= $total_count )
		{
			while ( $skip >= $total_count )
			{
				$skip -= $limit;
			}

			$tmp_skip = $skip;
			$tmp_limit = $limit;

			$evaluation_data = Array();
			if ( $_SESSION['show_expired'] )
			{
				$evaluation_temp_data = ibit_Evaluation::getExpiredEvaluationsByInstituteId( $institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id'] );
				$evaluation_data = array_merge( $evaluation_data,  $evaluation_temp_data );
			}
			if ( $_SESSION['show_current'] )
			{
				$evaluation_temp_data = ibit_Evaluation::getCurrentEvaluationsByInstituteId( $institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id'] );
				$evaluation_data = array_merge( $evaluation_data, $evaluation_temp_data	);
			}
			if ( $_SESSION['show_future'] )
			{
				$evaluation_temp_data = ibit_Evaluation::getFutureEvaluationsByInstituteId( $institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id'] );
				$evaluation_data = array_merge( $evaluation_data, $evaluation_temp_data	);
			}
		}

		if ( $total_count<=0 )
		{
			$skip = 0;
		}

		$evaluation_data_grouped = Array();
		foreach ($evaluation_data as $eval)
		{
			if (!isset( $evaluation_data_grouped[ $eval['template_id'] ] ) )
			{
				$item = Array();
				$item['template_id'] = $eval['template_id'];
				$item['template_title'] = $eval['evaluation_title'];
				$item['evaluations'] = Array();

				$evaluation_data_grouped[ $eval['template_id'] ] = $item;
			}
			array_push( $evaluation_data_grouped[ $eval['template_id'] ]['evaluations'], $eval );
		}

		$this->templatelite->assign( 'institute_view', true );
		$this->templatelite->assign( 'evaluation_data', $evaluation_data_grouped );
		$this->templatelite->assign( 'link_back', $this->parent->base_link.'&command=show_faculty&faculty_id='.ibit_Helper::getFacultyForInstitute( $institute_id ) );
		$this->templatelite->assign( 'link_delete', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&action=delete_evaluations&skip='.$skip );
		$this->templatelite->assign( 'link_edit', $this->parent->base_link.'&command=evaluation_details&skip='.$skip );
		$this->templatelite->assign( 'link_first_page', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&skip=0' );
		$this->templatelite->assign( 'link_last_page', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&skip='.( $total_count - ( $total_count % $limit ) ) );
		$this->templatelite->assign( 'link_page_back', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&skip='.( $skip - $limit ) );
		$this->templatelite->assign( 'link_page_next', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&skip='.( $skip + $limit ) );
		$this->templatelite->assign( 'skip', $skip );
		$this->templatelite->assign( 'total_count', $total_count );

		if ( $fakview )
		{
			$this->templatelite->display( 'fakadmin.institute_view.tpl' );
		}
		else
		{
			$this->templatelite->display( 'admin.evaluation_administration.institute_view.tpl' );
		}

	}
}
?>