<?php
/**
 * classes/ibit_Action_EvaluationParticipate.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.1
 */

/**
 * Klasse zum Teilnehmen an einer Umfrage.
 *
 * Diese Klasse bildet die Schnittstelle zum Teilnehmen an einer Umfrage. Es werden Funktionen zum Beantworten einer Frage und zum Speichern
 * der gegebenen Antworten angeboten.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.1
 */
class ibit_Action_EvaluationParticipate
{
	/**
	 * Datenbankverbindungsobjekt
	 * @var object $conn
	 */
	var $conn;

	/**
	 * Die Id der zu beantwortenden Evaluation
	 * @var int $evaluation_id
	 */
	var $evaluation_id;

	/**
	 * Die Id des Users, der an der Evaluation teilnimmt
	 * @var string $user_id
	 */
	var $user_id;

	/**
	 * Array mit den gegebenen Antworten
	 * @var array $answers
	 */
	var $answers;

	/**
	 * Konstruktor der Klasse.
	 * @param int $evaluation_id Id der zu verwendenden Evaluation
	 * @param string $user_id Id des Users, der teilnimmt
	 * @uses ibit_DatabaseConnection
	 * @uses ibit_Evaluation
	 */
	function ibit_Action_EvaluationParticipate( $evaluation_id, $user_id )
	{
		$this->conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$this->evaluation_id = $evaluation_id;
		$this->user_id = $user_id;

		$evaluation = new ibit_Evaluation( $this->evaluation_id );
		$evaluation->loadTemplate();

		$this->answers = Array();
		foreach ($evaluation->template->groups as $group)
		{
			$this->answers[ $group->getId() ] = Array();
			foreach ($group->questions as $question)
			{
				$item = Array();
				$this->answers[ $group->getId() ][ $question->getId() ] = $item;
			}
		}
	}

	/**
	 * Speichert eine gegebene Antwort in dem Antworten-Array.
	 * Gibt es die entsprechende Frage nicht in der Evaluationsvorlage, wird die Antwort verworfen.
	 * @param int $group_id Die Id der zur Frage gehrenden Gruppe
	 * @param int $question_id Die Id der Frage
	 * @param int $answer_id Die Id der gegebenen Antwort
	 * @param string $value Der Wert der Antwort
	 * @return boolean Gibt an, ob die Antwort eingetragen wurde.
	 */
	function answer( $group_id, $question_id, $answer_id, $value )
	{
		if ( !isset( $this->answers[ $group_id ][ $question_id ] ) )
		{
			return false;
		}
		$value = str_replace( "\r", "\n", $value );
		$value = str_replace( "\n\n", "\n", $value );
		$answer = Array( 'answer_id' => $answer_id, 'value' => $value );
		array_push( $this->answers[ $group_id ][ $question_id ], $answer );

		return true;
	}

	/**
	 * Beendet die Teilnahme und speichert die Antworten in der Datenbank.
	 */
	function store()
	{
		$sql_insert_answers = 'INSERT DELAYED INTO ibit_evaluation_answers (evaluation_id, evaluation_group_template_id, evaluation_question_template_id, evaluation_answer_template_id, value, timestamp) VALUES ';
		$sql_insert_user = 'INSERT INTO ibit_evaluation_user (evaluation_id, user_id, timestamp, hidden) VALUES (?, ?, NOW(), 0)';

		$answer_strings = Array();
		foreach ( $this->answers as $group_id=>$group_data )
		{
			foreach ( $group_data as $question_id=>$answers )
			{
				foreach ( $answers as $answer )
				{
					$data = Array();
					array_push( $data, $this->evaluation_id );
					array_push( $data, $group_id );
					array_push( $data, $question_id );
					array_push( $data, $answer['answer_id'] );
					array_push( $data, "'".str_replace( "'", "\'", $answer['value'] )."'" );

					$string = '('.implode(',', $data).', NOW())';
					array_push( $answer_strings, $string );
				}
			}
		}
		$this->conn->Execute( $sql_insert_answers.implode(',', $answer_strings) );

		$data = Array();
		array_push( $data, $this->evaluation_id );
		array_push( $data, $this->user_id );

		$this->conn->Execute($sql_insert_user, $data );
	}
}
?>