<?php
/**
 * classes/ibit_Action_Handler.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.1
 */

/**
 * Diese Klasse stellt die Basisklasse fr die Userinteraktionsklassen dar.
 *
 * Von dieser Klasse ausgehend werden entsprechend den im Request bergebenen Parameter die entsprechende Logikfunktionen
 * aufgerufen.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author     Ivn Marcos <ivan.marcos@gmx.net>
 * @package    IBIT_Evaluation
 * @subpackage Action_Handler
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.1
 */
class ibit_Action_Handler
{
	/**
	 * Enthlt eine Referenz auf das aufrufende Objekt
	 * @var object $parent
	 */
	var $parent;

	/**
	 * Referenz auf die Templateklasse
	 * @var object $templatelite
	 */
	var $templatelite;

	/**
	 * Erzeugter Link auf die Hauptseite des Plugins
	 * @var string $parent_link
	 */
	var $parent_link;

	/**
	 * Erzeugter Link auf die Hauptseite der aktuellen Sektion
	 * @var string $section_link
	 */
	var $section_link;

	/**
	 * Erzeugter Link auf die Seite der aktuellen Funktion
	 * @var string $base_link
	 */
	var $base_link;

	/**
	 * Konstruktor der Klasse.
	 * Die Referenzen auf globale oder bergebene Objekte werden erzeugt. Desweiteren werden bentigte Links erzeugt
	 * und die entsprechenden Logikfunktionen aufgerufen.
	 *
	 * @param object $parent Referenz auf das aufrufende Objekt
	 * @param string $default_section Standardsektion, die aufgerufen wird, falls keine Sektion bergeben wurde.
	 * @param string $default_function Standardfunction, die aufgerufen wird, falls keine Funktion bergeben wurde.
	 * @uses PluginEngine::getLink()
	 */
	function ibit_Action_Handler( $parent, $default_section, $default_function )
	{
		$this->parent = $parent;
		$this->templatelite =& $GLOBALS['templatelite'];

		$section = empty( $_REQUEST['section'] ) ? $default_section : $_REQUEST['section'];
		$function = empty( $_REQUEST['function'] ) ? $default_function : $_REQUEST['function'];

		$this->parent_link = PluginEngine::getLink( $this->parent );
		$this->section_link = $this->parent_link.'&section='.$section;
		$this->base_link = $this->parent_link.'&section='.$section.'&function='.$function;

		$method = $section.'_'.$function;

		if ( method_exists( $this, $method ) )
		{
			call_user_func( Array(&$this, $method ) );
		}
		else
		{
			$this->templatelite->append( 'messages_errors', '404 - Ungltiger Aufruf' );
		}
	}
}
?>