<?php
/**
 * classes/ibit_Action_Handler_Teacher.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.5
 */

/**
 * Diese Klasse enthlt alle Funktionen, die ein Dozent ausfhren kann.
 *
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action_Handler
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.5
 */
class ibit_Action_Handler_Teacher extends ibit_Action_Handler
{
	/**
	 * Id des Dozenten
	 * @var string $user_id
	 */
	var $user_id;

	/**
	 * Konstruktor der Klasse.
	 * Initialisiert die Klasse, indem der Konstruktor der Elternklasse mit dem bergebenen aufrufenden Objekt
	 * und den Standardwerten fr Sektion und Funktion aufgerufen wird.
	 *
	 * @param object $parent Referenz auf das aufrufende Objekt
	 * @param string $user_id Id des Dozenten
	 */
	function ibit_Action_Handler_Teacher( $parent, $user_id )
	{
		$this->user_id = $user_id;
		parent::ibit_Action_Handler( $parent, 'expired', 'index' );
	}

	/**
	 * Zeigt die Hauptseite der abgeschlossenen Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function expired_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId( $this->user_id, true );
		$this->templatelite->assign( 'evaluations', $evaluations['expired'] );
		$this->templatelite->assign( 'link_activate', $this->section_link.'&function=activate' );
		$this->templatelite->assign( 'link_comment', $this->section_link.'&function=comment' );
		$this->templatelite->assign( 'link_summary', $this->section_link.'&function=summary' );
		$this->templatelite->display( 'dozent.display_expired.tpl' );
	}

	/**
	 * Zeigt die Auswertung einer Evaluation an.
	 * @uses ibit_Action_Summary
	 */
	function expired_summary()
	{
		$evaluation_id = $_REQUEST['evaluation_id'];
		$summary = new ibit_Action_Summary( $this->parent , $evaluation_id );
		$summary->show();
	}

	/**
	 * Schaltet eine Evaluation frei oder sperrt sie.
	 * @uses ibit_Evaluation
	 */
	function expired_activate()
	{
		$evaluation_id = $_REQUEST['evaluation_id'];
		$visible_status = ( $_REQUEST['visible'] == 1 );

		$evaluation = new ibit_Evaluation( $evaluation_id );
		$evaluation->setVisible( $visible_status, $_SESSION['auth']->auth['uid']);
		$evaluation->save();

		$this->templatelite->append( 'messages_success', 'Ihre nderung wurde erfolgreich gespeichert.' );

		$this->expired_index();
	}

	/**
	 * Speichert einen Kommentar des Dozenten bzw. zeigt das Formular zum Eingeben an.
	 * @uses ibit_Evaluation
	 */
	function expired_comment()
	{
		$evaluation_id = $_REQUEST['evaluation_id'];

		if( !empty( $_REQUEST['action'] ) and $_REQUEST['action'] == "submit")
		{
			#speichern
			$evaluation = new ibit_Evaluation( $evaluation_id );
			$evaluation->setComment( $_REQUEST['comment'] );
			$evaluation->save();

			$this->templatelite->append( 'messages_success', 'Ihr Kommentar wurde erfolgreich gespeichert.' );

			$this->expired_index();
			return;
		}

		#eingabe feld anzeigen
		$evaluation = new ibit_Evaluation( $evaluation_id );
		$comment = $evaluation->getComment();

		$this->templatelite->assign( 'link_comment', $this->section_link.'&function=comment' );
		$this->templatelite->assign( 'evaluation_id', $evaluation_id );
		$this->templatelite->assign( 'comment', $comment );
		$this->templatelite->assign( 'link_back', $this->section_link );
		$this->templatelite->display( 'dozent.comment.tpl' );
	}

	/**
	 * Zeigt die Hauptseite der laufenden Evaluationen an.
	 * @uses ibit_Evaluation::getEvaluationDataByUserId()
	 */
	function running_index()
	{
		$evaluations = ibit_Evaluation::getEvaluationDataByUserId( $this->user_id, true );
		$this->templatelite->assign( 'evaluations', $evaluations['running'] );
		$this->templatelite->assign( 'link_participate', $this->section_link.'&function=participate' );
		$this->templatelite->display( 'dozent.display_running.tpl' );
	}
}
?>