<?php
/**
 * classes/ibit_DatabaseConnection.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.1
 */

/**
 * Diese Klasse stellt einen Datenbank-Layer dar, der bei Datenbank-Fehler die Fehler direkt anzeigen kann.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @package    IBIT_Evaluation
 * @subpackage Helper
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.1
 * @todo       Bei Update auf PHP5 $conn als statisch deklarieren, um die Verbindungen zur Datenbank zu minimieren.
 */
class ibit_DatabaseConnection
{
	/**
	 * Die zu nutzende Datenbankverbindung
	 * @var object $conn
	 */
	var $conn;

	/**
	 * Gibt an, ob Fehler angezeigt werden sollen oder nicht
	 * @var boolean $display_errors
	 */
	var $display_errors;

	/**
	 * Konstruktor
	 * @param boolean $display_errors Gibt an, ob Fehler angezeigt werden sollen oder nicht.
	 * @uses PluginEngine::getPluginDatabaseConnection() 
	 */
	function ibit_DatabaseConnection( $display_errors = false )
	{
		$this->conn =& PluginEngine::getPluginDatabaseConnection();
		$this->display_errors = $display_errors;
	}

	/**
	 * Fhrt eine bergebene SQL-Anfrage (mit Parametern) aus und zeigt ggf. die Fehler an
	 * @param string $sql SQL-Anfrage, die ausgefhrt werden soll
	 * @param mixed $params Optionale Parameter
	 * @return object AdoDB-ResultSet
	 * @uses AdoDB::Execute()
	 */
	function Execute( $sql, $params = null )
	{
		$resultSet = null;
		if ( $params === null )
		{
			$resultSet = $this->conn->Execute( $sql );
		}
		else
		{
			$resultSet = $this->conn->Execute( $sql, $params );
		}

		$error_message = $this->conn->ErrorMsg();
		if ( $this->display_errors and !empty( $error_message ) )
		{
			echo '<div style="border: 1px solid red; background-color: #FCC; padding: 3px">';
			echo '<dl style="margin: 0px; padding: 0px;">';
			echo '<dt>SQL error:</dt><dd><b>'.$error_message.'</b></dd>';
			echo '<dt>SQL:</dt><dd><i>'.$sql.'</i></dd/>';
			echo '<dt>Debug backtrace:</dt>';
			echo '<dd><ul>';
			$dbt = debug_backtrace();
			foreach ($dbt as $trace)
			{
				$trace['file'] = str_replace( $GLOBALS['ABSOLUTE_PATH_STUDIP'], '', str_replace('\\', '/', $trace['file'] ) );

				$output = Array();
				array_push( $output, 'File <b>'.$trace['file'].'</b>' );
				array_push( $output, 'Line <b>'.$trace['line'].'</b>' );
				if ( !empty( $trace['function'] ) )
				{
					array_push( $output, 'Function <b>'.$trace['function'].'()</b>' );
				}
				echo '<li>'.implode('<br/>', $output ).'</li>';
			}
			echo '</ul></dd>';
			echo '</dl>';
			echo '</div>';
		}
		return $resultSet;
	}

	/**
	 * Gibt die zuletzt eingefgte Id eines auto_increment-Feldes zurck.
	 * @return int Zuletzt eingefgte Id
	 * @uses AdoDB::Insert_Id()
	 */
	function Insert_Id()
	{
		return $this->conn->Insert_Id();
	}

	/**
	 * Prpariert eine SQL-Anfrage fr die weitere Verarbeitung (Dummy-Funktion)
	 * @param string $sql Die SQL-Anfrage
	 * @return string Unvernderte SQL-Abfrage
	 */
	function prepare( $sql )
	{
		return $sql;
	}

	/**
	 * Liefert die Anzahl der von der letzten Anfrage beeinflussten Zeilen zurck.
	 * @return int Anzahl der beeinflussten Zeilen
	 * @uses AdoDB::Affected_Rows();
	 */
	function Affected_Rows()
	{
		return $this->conn->Affected_Rows();
	}

	/**
	 * Schliesst die Datenbankverbindung.
	 * @return boolean Erfolgsmeldung
	 * @uses AdoDB::Close()
	 */
	function Close()
	{
		return $this->conn->Close();
	}
}
?>