<?php
/**
 * classes/ibit_EvaluationSeminar.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.2
 */

/**
 * Diese Klasse kapselt die Zugriffe auf alle fr das Plugin ntige Daten eines Seminars.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.7
 */
class ibit_EvaluationSeminar
{
	/**
	 * Datenbankverbindungsobjekt
	 * @var object $conn
	 */
	var $conn;

	/**
	 * SQL-Statement zum Laden der relevanten Daten eines Seminars
	 * @var string $sql_load_seminar
	 */
	var $sql_load_seminar = 'SELECT s.Name AS seminar_name, s.Institut_id AS institute_id, i.Name as institute_name, i.fakultaets_id AS fakultaet_id FROM seminare AS s LEFT JOIN Institute AS i USING(Institut_id) WHERE s.seminar_id = ?';

	/**
	 * SQL-Statement zum Auslesen der Anzahl der Teilnehmer eines Seminars
	 * @var string $sql_count_members
	 */
	var $sql_count_members = "SELECT COUNT(user_id) AS members FROM seminar_user WHERE seminar_id = ? AND status NOT IN ('dozent', 'admin', 'tutor')";

	/**
	 * SQL-Statement zum Auslesen der Namen der Dozenten
	 * @var string $sql_load_Teachers
	 */
	var $sql_get_teachers = "SELECT CONCAT( c.title_front, ' ', b.Vorname, ' ', b.Nachname ) AS name FROM ( seminar_user AS a LEFT JOIN auth_user_md5 AS b USING ( user_id ) ) LEFT JOIN user_info AS c USING ( user_id ) WHERE a.seminar_id = ? AND a.status = 'dozent'";

	/**
	 * Id des Seminars
	 * @var string $seminar_id
	 */
	var $seminar_id;

	/**
	 * Name des Seminars
	 * @var string $seminar_name
	 */
	var $seminar_name;

	/**
	 * Id des Instituts des Seminars
	 * @var string $institute_id
	 */
	var $institute_id;

	/**
	 * Name des Institut des Seminars
	 * @var string $institute_name
	 */
	var $institute_name;

	/**
	 * Id der Fakultt des Instituts des Seminars
	 * @var string $faculty_id
	 */
	var $fakultaet_id;

	/**
	 * Anzahl der Teilnehmer des Seminars
	 * @var int $members
	 */
	var $members;

	/**
	 * Namen der Dozenten
	 * @var array $teachers
	 */
	var $teachers;

	/**
	 * Der Konstruktor der Klasse.
	 * @param string $seminar_id Id des Seminars
	 * @uses ibit_DatabaseConnection
	 */
	function ibit_EvaluationSeminar( $seminar_id )
	{
		$this->conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$this->seminar_id = $seminar_id;

		$this->load();
	}

	/**
	 * Ldt die relevanten Daten des Seminars aus der Datenbank
	 * @return boolean Gibt an, ob das Laden erfolgreich war.
	 */
	function load()
	{
		$seminar_result = $this->conn->Execute( $this->sql_load_seminar, $this->seminar_id );
		if ( !$seminar_result or $seminar_result->EOF )
		{
			return false;
		}
		$this->seminar_name = $seminar_result->fields['seminar_name'];
		$this->institute_name = $seminar_result->fields['institute_name'];
		$this->institute_id = $seminar_result->fields['institute_id'];
		$this->faculty_id = $seminar_result->fields['fakultaet_id'];
		$seminar_result->Close();

		$teachers = array();
		$teachers_result = $this->conn->Execute( $this->sql_get_teachers, $this->seminar_id );
		while ( !$teachers_result->EOF )
		{
			array_push( $teachers, $teachers_result->fields['name'] );
			$teachers_result->MoveNext();
		}
		$teachers_result->Close();
		$this->teachers = $teachers;

		$this->members = 0;
		if ( ($member_result = $this->conn->Execute( $this->sql_count_members, $this->seminar_id ) ) and !$member_result->EOF )
		{
			$this->members = $member_result->fields['members'];
			$member_result->Close();
		}
		return true;
	}

	/**
	 * Liefert den Namen des Seminars zurck.
	 * @return string Name des Seminars
	 */
	function getName()
	{
		return $this->seminar_name;
	}

	/**
	 * Liefert die Anzahl der Teilnehmer an dem Seminar zurck.
	 * @return int Anzahl der Teilnehmer an dem Seminar
	 */
	function getMembers()
	{
		return $this->members;
	}

	/**
	 * Liefert dieNamen der Dozenten zurck
	 * @return array Dozenten
	 */
	function getTeachers()
	{
		return $this->teachers;
	}

	/**
	 * Bricht das Objekt in ein Array auf.
	 * Die Rckgabe sieht dabei folgendermassen aus:<br/>
	 * <pre>
	 *    [
	 *     seminar_id     => Id des Seminars,
	 *     seminar_name   => Name des Seminars,
	 *     institute_id   => Id des Instituts des Seminars,
	 *     institute_name => Name des Instituts des Seminars,
	 *     fakultaet_id   => Id der Fakultt des Seminars,
	 *     members        => Anzahl der Teilnehmer an dem Seminar
	 *    ]
	 * </pre>
	 *
	 * @return array Seminardaten
	 */
	function flattenToArray()
	{
		$result = Array();
		$result['seminar_id'] = $this->seminar_id;
		$result['seminar_name'] = $this->seminar_name;
		$result['institute_name'] = $this->institute_name;
		$result['institute_id'] = $this->institute_id;
		$result['fakultaet_id'] = $this->faculty_id;
		$result['members'] = $this->members;

		return $result;
	}

##########################
## STATISCHE FUNKTIONEN ##
##########################

	/**
	 * Liefert die aggregierten Teilnehmer an den Seminaren eines Instituts fr ein bestimmtes Semester zurck.
	 * @param string $institute_id Id des Instituts
	 * @param string $semester_id Id des Semesters
	 * @return int Anzahl der Teilnehmer an den Seminaren des Institutes in dem entsprechenden Semester
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function getSeminarMemberCountByInstituteId( $institute_id, $semester_id, $additional_where_clause = '' )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_get_seminars = 'SELECT seminar_id FROM ibit_evaluation WHERE institut_id = ? AND semester_id = ?';
		$sql_get_member_count = "SELECT COUNT(user_id) AS member_count FROM seminar_user WHERE seminar_id IN (###IN_CLAUSE###) AND status NOT IN ('dozent', 'admin', 'tutor')";

		if ( !empty( $additional_where_clause ) )
		{
			$sql_get_seminars .= ' AND '.$additional_where_clause;
		}

		if ( !$seminar_result = $conn->Execute( $sql_get_seminars, Array( $institute_id, $semester_id ) ) )
		{
			return -1;
		}

		$seminars = Array();
		while ( !$seminar_result->EOF )
		{
			array_push( $seminars, $seminar_result->fields['seminar_id'] );
			$seminar_result->MoveNext();
		}
		$seminar_result->Close();

		if ( empty( $seminars ) )
		{
			return 0;
		}
		$sql_get_member_count = str_replace( '###IN_CLAUSE###', "'".implode("','", $seminars)."'", $sql_get_member_count );

		$count = 0;
		if ( $count_result = $conn->Execute( $sql_get_member_count ) and !$count_result->EOF )
		{
			$count = $count_result->fields['member_count'];
			$count_result->Close();
		}

		$conn->Close();

		return $count;
	}

	/**
	 * Liefert die aggregierten Teilnehmer an den Seminaren einer Fakultt fr ein bestimmtes Semester zurck.
	 * @param string $faculty_id Id der Fakultt
	 * @param string $semester_id Id des Semesters
	 * @return int Anzahl der Teilnehmer an den Seminaren des Institutes in dem entsprechenden Semester
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function getSeminarMemberCountByFacultyId( $faculty_id, $semester_id, $additional_where_clause = '' )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_get_seminars = 'SELECT seminar_id FROM ibit_evaluation WHERE fakultaet_id = ? AND semester_id = ?';
		$sql_get_member_count = "SELECT COUNT(user_id) AS member_count FROM seminar_user WHERE seminar_id IN (###IN_CLAUSE###) AND status NOT IN ('dozent', 'admin', 'tutor')";

		if ( !empty( $additional_where_clause ) )
		{
			$sql_get_seminars .= ' AND '.$additional_where_clause;
		}

		if ( !$seminar_result = $conn->Execute( $sql_get_seminars, Array( $faculty_id, $semester_id ) ) )
		{
			return -1;
		}

		$seminars = Array();
		while ( !$seminar_result->EOF )
		{
			array_push( $seminars, $seminar_result->fields['seminar_id'] );
			$seminar_result->MoveNext();
		}
		$seminar_result->Close();

		if ( empty( $seminars ) )
		{
			return 0;
		}

		$sql_get_member_count = str_replace( '###IN_CLAUSE###', "'".implode("','", $seminars)."'", $sql_get_member_count );

		$count = 0;
		if ( $count_result = $conn->Execute( $sql_get_member_count ) and !$count_result->EOF )
		{
			$count = $count_result->fields['member_count'];
			$count_result->Close();
		}

		$conn->Close();

		return $count;
	}

	/**
	 * Ldt die relevanten Infos zu einer Menge von Seminaren.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     Seminar_id           => Id des Seminars,
	 *     Institut_id          => Id des Instituts des Seminars,
	 *     Fakultaets_id        => Id der Fakultt des Seminars,
	 *     Name                 => Name des Seminars,
	 *     VeranstaltungsNummer => Veranstaltungsnummer des Seminars,
	 *     Anzahl               => Anzahl der Teilnehmer an dem Seminar,
	 *     ects                 => ECTS-Punkte des Seminars
	 *    ]{0..x}
	 *
	 * @param array $seminar_ids Ids der Seminare
	 * @return array Seminardaten
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function getSeminarData( $seminar_ids )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		if ( !is_array( $seminar_ids ) )
		{
			$seminar_ids = Array( $seminar_ids );
		}

		# Seminar-Ids in das von StudIP benutzte gepaddete Format bringen
		foreach ( $seminar_ids as $idx=>$seminar_id )
		{
			$seminar_ids[$idx] = str_pad( $seminar_id, 32, '0', STR_PAD_LEFT );
		}

		$seminar_data = Array();
		$seminar_string = "'".implode("','", array_unique( $seminar_ids ))."'";
		$sql_load_seminars = "SELECT s.Seminar_id AS Seminar_id, s.Name AS Name, VeranstaltungsNummer, SUM( IF( u.status NOT IN ('dozent', 'tutor', 'admin'), 1, 0 ) ) AS user_count, ects, i.fakultaets_id AS fakultaet_id, s.Institut_id AS institut_id, s.art AS art FROM seminare AS s LEFT JOIN seminar_user AS u USING( Seminar_id ) LEFT JOIN seminar_inst AS si ON( s.Seminar_id=si.seminar_id) LEFT JOIN Institute AS i ON (s.Institut_id=i.Institut_id OR si.institut_id=i.institut_id) WHERE s.Seminar_id IN (".$seminar_string.") AND fakultaets_id IS NOT NULL GROUP BY s.Seminar_id";
		if ( !$result = $conn->Execute( $sql_load_seminars ) )
		{
			return false;
		}
		while ( !$result->EOF )
		{
			$seminar = Array();
			$seminar['Seminar_id'] = $result->fields['Seminar_id'];
			$seminar['Name'] = $result->fields['Name'];
			$seminar['VeranstaltungsNummer'] = $result->fields['VeranstaltungsNummer'];
			$seminar['Teilnehmer_Seminar'] = $result->fields['user_count'];
			$seminar['ects'] = $result->fields['ects'];
			$seminar['Fakultaets_id'] = empty( $result->fields['fakultaet_id'] ) ? 'k.A.' : $result->fields['fakultaet_id'];
			$seminar['Institut_id'] = $result->fields['institut_id'];
			$seminar['Art'] = $result->fields['art'];

			$seminar_data[ $seminar['Seminar_id'] ] = $seminar;

			$result->MoveNext();
		}
		$result->Close();

		$conn->Close();

		return $seminar_data;
	}

	/**
	 * Sucht ein Seminar anhand eines Teils des Namens, Veranstaltungsnummer und eines gegebenen Semesters.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     Seminar_id           => Id des Seminars,
	 *     Institut_id          => Id des Instituts des Seminars,
	 *     Fakultaets_id        => Id der Fakultt des Seminars,
	 *     Name                 => Name des Seminars,
	 *     VeranstaltungsNummer => Veranstaltungsnummer des Seminars,
	 *     Anzahl               => Anzahl der Teilnehmer an dem Seminar,
	 *     ects                 => ECTS-Punkte des Seminars
	 *    ]{0..x}
	 *
	 * @param string $name Teil des Namens, nach dem gesucht werden soll
	 * @param string $number Teil der Veranstaltungsnummer
	 * @param string $semester_id Id des Semesters
	 * @return array Seminardaten
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function searchSeminarByNameAndSemester( $name, $number, $semester_id )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_search_seminars = "SELECT s.Seminar_id AS Seminar_id, s.Name AS Name, VeranstaltungsNummer, SUM( IF( u.status NOT IN ('dozent', 'tutor', 'admin'), 1, 0 ) ) AS user_count, ects, i.fakultaets_id AS fakultaet_id, s.Institut_id AS institut_id, i.Name AS Institut_Name FROM seminare AS s LEFT JOIN seminar_user AS u USING( Seminar_id ) LEFT JOIN seminar_inst AS si ON(s.Seminar_id=si.seminar_id) LEFT JOIN Institute AS i ON (s.Institut_id=i.Institut_id OR si.institut_id=i.institut_id) INNER JOIN semester_data AS sem ON (sem.semester_id=?) WHERE ##searchcriteria## AND start_time BETWEEN sem.beginn AND sem.ende AND fakultaets_id IS NOT NULL GROUP BY s.Seminar_id";

		$search_criteria = Array();
		if ( !empty( $name ) )
		{
			array_push( $search_criteria, "s.Name LIKE '%".$name."%'" );
		}
		if ( !empty( $number ) )
		{
			array_push( $search_criteria, "s.VeranstaltungsNummer LIKE '%".$number."%'" );
		}
		if ( empty( $search_criteria ) )
		{
			return Array();
		}
		$sql_search_seminars = str_replace( '##searchcriteria##', implode(' AND ', $search_criteria), $sql_search_seminars);

		if ( !$result = $conn->Execute( $sql_search_seminars, Array($semester_id) ) )
		{
			return Array();
		}
		$seminar_data = Array();
		while ( !$result->EOF )
		{
			$seminar = Array();
			$seminar['Seminar_id'] = $result->fields['Seminar_id'];
			$seminar['Name'] = $result->fields['Name'];
			$seminar['VeranstaltungsNummer'] = $result->fields['VeranstaltungsNummer'];
			$seminar['Teilnehmer_Seminar'] = $result->fields['user_count'];
			$seminar['ects'] = $result->fields['ects'];
			$seminar['Fakultaets_id'] = $result->fields['fakultaet_id'];
			$seminar['Institut_id'] = $result->fields['institut_id'];
			$seminar['Institut_Name'] = $result->fields['Institut_Name'];

			$seminar_data[ $seminar['Seminar_id'] ] = $seminar;

			$result->MoveNext();
		}
		$result->Close();

		$conn->Close();

		return $seminar_data;
	}

	function searchSeminarByNameAndDozent( $veranstaltung, $dozent )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_search_seminars = "SELECT s.Seminar_id AS Seminar_id, s.Name AS veranstaltung, b.user_id AS user_id, u.Vorname, u.Nachname , c.name AS semester FROM seminare AS s LEFT JOIN seminar_user AS b USING ( Seminar_id ) LEFT JOIN auth_user_md5 AS u USING ( user_id ) LEFT JOIN semester_data AS c ON c.beginn = s.start_time INNER JOIN ibit_evaluation AS d on d.seminar_id = s.Seminar_id WHERE b.status = 'dozent' ##searchcriteria## GROUP BY s.Seminar_id ORDER BY c.semester_id DESC";

		$search_criteria = '';
		if ( !empty( $veranstaltung ) )
		{
			$search_criteria .= " AND s.Name LIKE '%".$veranstaltung."%'";
		}
		if ( !empty( $dozent ) )
		{
			$search_criteria .=" AND ( u.Vorname LIKE '%".$dozent."%' OR u.Nachname LIKE '%".$dozent."%' )";
		}

		$sql_search_seminars = str_replace( '##searchcriteria##', $search_criteria, $sql_search_seminars);
		//echo $sql_search_seminars;

		if ( !$result = $conn->Execute( $sql_search_seminars ) )
		{
			return Array();
		}
		$seminar_data = Array();
		while ( !$result->EOF )
		{
			$seminar = Array();
			$seminar['Seminar_id'] = $result->fields['Seminar_id'];
			$seminar['Name'] = $result->fields['veranstaltung'];
			$seminar['Semester'] = $result->fields['semester'];
			$seminar['Dozent'] = $result->fields['Vorname']." ".$result->fields['Nachname'];
			$seminar_data[ $seminar['Seminar_id'] ] = $seminar;

			$result->MoveNext();
		}
		$result->Close();

		$conn->Close();

		return $seminar_data;
	}

	/**
	 * Liefert alle IDs von Tutoren zu einer Veranstaltung zurck
	 *
	 * @param string $seminar_id Ids des Seminares
	 * @return array IDs der Tutoren
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function getTutorsForSeminar($seminar_id)
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$tutor_data = Array();

		$sql_load_tutors = "SELECT user_id FROM seminar_user WHERE Seminar_id = ? AND status='tutor'";
		if ( !$result = $conn->Execute( $sql_load_tutors, $seminar_id ) )
		{
			return $tutor_data;
		}
		while ( !$result->EOF )
		{
			array_push( $tutor_data, $result->fields['user_id'] );
			$result->MoveNext();
		}
		$result->Close();
		$conn->Close();

		return $tutor_data;
	}

	/**
	 * Liest die relevanten Dozentendaten einer Menge von Seminaren aus.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     user_id    => User-Id des Dozenten,
	 *     Vorname    => Vorname des Dozenten,
	 *     Nachname   => Nachname des Dozenten,
	 *     seminar_id => Id des Seminars
	 *    ]{0..x}
	 *
	 * @param array $seminar_ids Ids der Seminare
	 * @return array Dozentendaten
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function getDozentDataForSeminar( $seminar_ids )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		if ( !is_array( $seminar_ids ) )
		{
			$seminar_ids = Array( $seminar_ids );
		}

		$dozent_data = Array();
		$seminar_string = "'".implode("','", array_unique( $seminar_ids ))."'";
		$sql_load_dozenten = "SELECT s.Seminar_id AS Seminar_id, s.user_id AS user_id, Vorname, Nachname FROM seminar_user AS s LEFT JOIN auth_user_md5 AS u USING( user_id ) WHERE s.Seminar_id IN (".$seminar_string.") AND s.status='dozent'";
		if ( !$result = $conn->Execute( $sql_load_dozenten ) )
		{
			return false;
		}
		while ( !$result->EOF )
		{
			$dozent = Array();
			$dozent['user_id'] = $result->fields['user_id'];
			$dozent['Vorname'] = $result->fields['Vorname'];
			$dozent['Nachname'] = $result->fields['Nachname'];
			$dozent['seminar_id'] = $result->fields['Seminar_id'];

			array_push( $dozent_data, $dozent );
			$result->MoveNext();
		}
		$result->Close();

		$conn->Close();

		return $dozent_data;
	}
}
?>