<?php
/**
 * classes/ibit_EvaluationSummary.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.3
 */

/**
 *
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.3
 *
 */
class ibit_EvaluationSummary {

	/**
	 * Datenbankverbindungsobjekt
	 * @var object $conn
	 */
	var $conn = null;

	/**
	 * Die ID der Evaluation
	 * @var string $evaluation_id
	 */
	var $evaluation_id = null;

	var $admin_id = null;

	var $cachepath = null;

	var $cache_filename = null;

	var $min_users = null;

    /**
     * Konstruktor
     */
    function ibit_EvaluationSummary( $evaluation_id = null , $admin_id = null ) {
    	$this->conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );
    	$this->evaluation_id = $evaluation_id;
    	$this->admin_id = $admin_id;
    	$this->cachepath = $GLOBALS['ibit_eval_summarycachepath'];
    	$this->cache_filename = md5("auswertung".$this->evaluation_id);
    	$this->min_users = $GLOBALS['ibit_eval_minusers'];
    }

    /**
     * Grunddaten liefern wie Evalname, Teilnehmer, Datum etc. pp.
     */
    function getOverview()
    {
		$conn = isset( $this->conn ) ? $this->conn : new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		# Anzahl der teilnehmenden Studenten an der Evaluation ermitteln
		$sql_get_user_count = 'SELECT SUM(hidden<>1) AS user_count FROM ibit_evaluation_user WHERE evaluation_id = ?';
		if ( !$user_count_result = $conn->Execute( $sql_get_user_count, $this->evaluation_id ) or $user_count_result->EOF )
		{
			$users = false;
			return false;
		}
		$user_count = $user_count_result->fields['user_count'];
		$user_count_result->Close();
		/*if ( $user_count < $users )
		{
			$users = $user_count;
			return false;
		}*/
		$users = $user_count;
		$overview = array();

		if(!empty($this->admin_id))
		{
			$overview['user_id'] = $this->admin_id;
		}

		#Daten holen
		$evaluation = new ibit_Evaluation($this->evaluation_id);
		$seminar = new ibit_EvaluationSeminar($evaluation->getSeminarId());
		$template = new ibit_EvaluationTemplate($evaluation->getTemplateId());

		#Daten ins Ausgabearray speichern.
		$overview['id']= $this->evaluation_id;
		$overview['users']= $users;
		$overview['start_date']= $evaluation->getStartDate();
		$overview['stop_date']= $evaluation->getStopDate();
		$overview['create_date']= $evaluation->getCreateDate();
		$overview['comment']= $evaluation->getComment();

		$overview['template_name'] = $template->getTitle();

		if($evaluation->isVisible())
		{
			$overview['visible_date']= $evaluation->getVisibleDate();
			$overview['visible_status']= true;
		}

		$overview['seminar_id']= $evaluation->getSeminarId();
		$overview['seminar_name']= $seminar->getName();
		$overview['seminar_teachers']= $seminar->getTeachers();
		$overview['seminar_countteachers']= count($seminar->getTeachers());
		$overview['seminar_members']= $seminar->getMembers();
		$overview['participants_ratio']= ($users / $seminar->getMembers() * 100);

		return $overview;
    }

    /**
	 * Ldt die Antworten zu einer Evaluation.
	 * @param int $evaluation_id Id der Evaluation
	 * @param int $users Minimale Anzahl an teilnehmenden Studenten (Rckgabe ist die tatschliche Anzahl der Teilnehmer oder false bei Fehlern)
	 * @return mixed false bei Fehlern oder zu wenig Teilnehmern, ansonsten ein Array mit den Daten
	 * @static
	 * @uses ibit_DatabaseConnection
	 * @todo Dokumentation, Aggregation
	 */
	function getAnswers()
	{
		# /cache-Pfad im Tempverzeichnis anlegen, falls er nicht existiert
		if ( !( is_dir($this->cachepath ) or @mkdir( $this->cachepath ) ) )
		{
			//$this->template->append( 'messages_errors', 'Fehler beim Erstellen des Cache-Verzeichnisses.');
			return;
		}

		# Serialisiertes Objekt laden und als Array zurckgeben
		if(file_exists($this->cachepath.$this->cache_filename) && !EVAL_FORCE)
		{
			$serialized_result = file_get_contents( $this->cachepath.$this->cache_filename );
			return unserialize($serialized_result);
		}
		$users = true;
		$conn = isset( $this->conn ) ? $this->conn : new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		# Anzahl der teilnehmenden Studenten an der Evaluation ermitteln
		$sql_get_user_count = 'SELECT SUM(hidden<>1) AS user_count FROM ibit_evaluation_user WHERE evaluation_id = ?';
		if ( !$user_count_result = $conn->Execute( $sql_get_user_count, $this->evaluation_id ) or $user_count_result->EOF )
		{
			$users = false;
			return false;
		}
		$user_count = $user_count_result->fields['user_count'];
		$user_count_result->Close();
		if ( $user_count < $users )
		{
			$users = $user_count;
			return false;
		}
		$users = $user_count;

		$result = Array();
		$group_ids = Array();
		$question_ids = Array();
		$answer_ids = Array();

		# Struktur laden
		$sql_load_structure = 'SELECT evaluation_group_template_id, q.evaluation_question_template_id, a.evaluation_answer_template_id AS evaluation_answer_template_id, a.text AS answer_text, a.value AS answer_value, group_position, question_position, a.position AS answer_position FROM ibit_evaluation_links AS l INNER JOIN ibit_evaluation AS e USING( evaluation_template_id ) LEFT JOIN ibit_evaluation_question_templates AS q ON (l.evaluation_question_template_id=q.evaluation_question_template_id) LEFT JOIN ibit_evaluation_answer_templates AS a ON (q.evaluation_answer_type_id=a.evaluation_answer_type_id) WHERE evaluation_id = ? ORDER BY group_position ASC, question_position ASC';
		if ( !$structure_result = $conn->Execute( $sql_load_structure, $this->evaluation_id ) or $structure_result->EOF )
		{
			return false;
		}
		while ( !$structure_result->EOF )
		{
			$group_id = $structure_result->fields['evaluation_group_template_id'];
			$group_position = $structure_result->fields['group_position'];
			$question_id = $structure_result->fields['evaluation_question_template_id'];
			$question_position = $structure_result->fields['question_position'];
			$answer_id = $structure_result->fields['evaluation_answer_template_id'];
			$answer_position = $structure_result->fields['answer_position']+1;
			$answer_text = $structure_result->fields['answer_text'];
			$answer_value = $structure_result->fields['answer_value'];
			if ( empty( $result[ $group_id ] ) )
			{
				$result[ $group_id ] = Array( 'group_id' => $group_id, 'position' => $group_position, 'questions' => Array() );
				array_push( $group_ids, $group_id );
			}
			if ( empty( $result[ $group_id ]['questions'][ $question_id ] ) )
			{
				$result[ $group_id ]['questions'][ $question_id ] = Array( 'question_id' => $question_id, 'position' => $question_position, 'answers' => Array() );
				array_push( $question_ids, $question_id );
			}
			$result[ $group_id ]['questions'][ $question_id ]['answers'][ $answer_id ] = Array( 'answer_id' => $answer_id, 'position' => $answer_position, 'count' => 0, 'text' => $answer_text, 'value' => $answer_value, 'values' => Array() );

			$structure_result->MoveNext();
		}
		$structure_result->Close();

		# Antworten auslesen
		$sql_load_answers = 'SELECT evaluation_group_template_id, evaluation_question_template_id, evaluation_answer_template_id, TRIM(value) AS value, COUNT(*) AS value_count FROM ibit_evaluation_answers WHERE evaluation_id = ? GROUP BY evaluation_group_template_id, evaluation_question_template_id, evaluation_answer_template_id, LOWER(TRIM(value))';
		if ( !$answer_result = $conn->Execute( $sql_load_answers, $this->evaluation_id ) )
		{
			return false;
		}
		while ( !$answer_result->EOF )
		{
			$group_id = $answer_result->fields['evaluation_group_template_id'];
			$question_id = $answer_result->fields['evaluation_question_template_id'];
			$answer_id = $answer_result->fields['evaluation_answer_template_id'];
			$value = $answer_result->fields['value'];
			$value_count = $answer_result->fields['value_count'];

			$answer = Array();
			$answer['value'] = $value;
			$answer['count'] = $value_count;
			$result[ $group_id ]['questions'][ $question_id ]['answers'][ $answer_id ]['count'] += $answer['count'];

			array_push( $result[ $group_id ]['questions'][ $question_id ]['answers'][ $answer_id ]['values'], $answer );

			$answer_result->MoveNext();
		}
		$answer_result->Close();

		# Gruppendaten auslesen
		$group_string = "'".implode( "','", array_unique( $group_ids ) )."'";
		$sql_load_group_data = 'SELECT evaluation_group_template_id, title, description FROM ibit_evaluation_group_templates WHERE evaluation_group_template_id IN ('.$group_string.')';
		if ( !$group_result = $conn->Execute( $sql_load_group_data ) )
		{
			return false;
		}

		$group_data = Array();
		while ( !$group_result->EOF)
		{
			$group = Array();
			$group['title'] = $group_result->fields['title'];
			$group['description'] = $group_result->fields['description'];
			$group_data[ $group_result->fields['evaluation_group_template_id'] ] = $group;

			$group_result->MoveNext();
		}
		$group_result->Close();

		# Fragendaten und Antworttypen auslesen
		$question_string = "'".implode( "','", array_unique( $question_ids ) )."'";
		$sql_load_question_data = 'SELECT evaluation_question_template_id, q.title AS title, q.text AS text, t.title AS answer_title, t.description AS answer_description, t.html_type AS html_type FROM ibit_evaluation_question_templates AS q LEFT JOIN ibit_evaluation_answer_types AS t USING( evaluation_answer_type_id ) WHERE evaluation_question_template_id IN ('.$question_string.')';
		if ( !$question_result = $conn->Execute( $sql_load_question_data ) )
		{
			return false;
		}

		$question_data = Array();
		while ( !$question_result->EOF )
		{
			$question_id = $question_result->fields['evaluation_question_template_id'];

			$question = Array();
			$question['title'] = $question_result->fields['title'];
			$question['text'] = $question_result->fields['text'];
			$question['answer_title'] = $question_result->fields['answer_title'];
			$question['answer_description'] = $question_result->fields['answer_description'];
			$question['html_type'] = $question_result->fields['html_type'];
			$question_data[ $question_id ] = $question;

			$question_result->MoveNext();
		}
		$question_result->Close();

		# Daten ins Array fllen
		foreach ( $result as $group_idx => $group )
		{
			$group['title'] = $group_data[ $group_idx ]['title'];
			$group['description'] = $group_data[ $group_idx ]['description'];
			foreach ( $group['questions'] as $question_idx => $question )
			{
				$question['title'] = $question_data[ $question_idx ]['title'];
				$question['text'] = $question_data[ $question_idx ]['text'];
				$question['answer_title'] = $question_data[ $question_idx ]['answer_title'];
				$question['answer_description'] = $question_data[ $question_idx ]['answer_description'];
				$question['html_type'] = $question_data[ $question_idx ]['html_type'];

				$answer_count = 0;
				$answer_countonly = 0;
				foreach( $question['answers'] as $answer_idx => $answer )
				{
					$answer_count = $answer_count + $answer['count'];
					if($answer['value'] != '-1')
					{
						$answer_countonly = $answer_countonly + $answer['count'];
					}
				}
				$question['answer_count'] = $answer_count;
				$question['answer_countonly'] = $answer_countonly;
				foreach( $question['answers'] as $answer_idx => $answer )
				{
					if($answer_count > 0)
					{
						$question['answers'][$answer_idx]['ratio'] = ($answer['count'] / $answer_count) * 100;
					}
					if($answer_countonly > 0)
					{
						$question['answers'][$answer_idx]['ratioonly'] = ($answer['count'] / $answer_countonly) * 100;
					}
				}
				if($question['html_type'] == 'polskala' || $question['html_type']=='select')
				{
					$question['median'] = $this->calculateMedian($question['answers'], $answer_countonly);
					$question['average'] = $this->calculateAverage($question['answers'], $answer_countonly);
					$question['deviation'] = $this->calculateDeviation($question['answers'], $answer_countonly, $question['average']);
				}

				#GRAFIKTYP AUS DB HOLEN
				if(!empty($this->admin_id))
				{
					$question['chart_type'] = ibit_EvaluationSummaryView::getAdminViewForQuestion( $this->evaluation_id, $group_idx, $question_idx, $this->admin_id );
				}
				else
				{
					$question['chart_type'] = ibit_EvaluationSummaryView::getUserViewForQuestion( $this->evaluation_id, $group_idx, $question_idx );
				}
				$question['imagehash'] = md5($this->evaluation_id."_".$question['question_id']."_".$question['position']."_".$question['chart_type']);

				#GRAFIK ERZEUGEN
				if($question['html_type'] != 'text' || $question['html_type']!='textarea')
				{
					#echo "Grafik wird erzeugen... ";
					$graphic = new ibit_Graphics($this->evaluation_id, $GLOBALS['ibit_eval_imagesettings']);
					$graphic->createImage($question);
					#echo "...fertig.<br/>";
				}

				$group['questions'][ $question_idx ] = $question;
			}
			$result[ $group_idx ] = $group;
		}

		# Ergebnis serialisieren und speichern
		$file_handle = fopen( $this->cachepath.$this->cache_filename, 'w' );
		$cached_result = serialize($result);
		fputs( $file_handle, $cached_result );
		fclose( $file_handle );

		# Daten zurckgeben
		return $result;
	}

		/**
	 * Mittelwert berechnen
	 *
	 * @param array $answers - Antwortenblock
	 * @return float Mittelwert mit 2 Nachkommastellen
	 */
	function calculateAverage($answers, $total){
		$points = 0;
		$result = 0;
		#echo "berechnung durchschnitt ";
		foreach($answers as $answer){
			#echo " wert: ".$answer['value']." anzahl: ".$answer['count'];
			if($answer['value'] != '-1')
			{
				$points = $points + ($answer['count'] * $answer['value']);
				#echo " berechneter wert: ".$points;
			}
		}
		$result = round($points/$total, 2);
		#echo "<br/>";
		return $result;
	}

	/**
	 * Median berechnen
	 *
	 * @param array $answers - Antwortenblock
	 * @param int $total - Gesamtanzahl Antworten
	 * @return int Median
	 */
	function calculateMedian($answers, $total){
		$before = 0;
		$whole = 0;
		$median = round($total/2, 0);
		foreach($answers as $answer){
			if($answer['value'] != '-1'){
				$whole = $whole + $answer['count'];
				if($before < $median && $median <= $whole){
					$result = $answer['value'];

				}
				$before = $before + $answer['count'];
			}
		}
		return $result;
	}

	/**
	 * Standardabweichung berechnen
	 *
	 * @param array $answers - Antwortenblock
	 * @param int $total - Gesamtanzahl Antworten
	 * @param float $average - Mittelwert
	 * @return float $result mit 2 Nachkommastellen
	 */
	function calculateDeviation($answers, $total, $average){
		#echo "gesamtantworten: ".$total;
		if($total != 0){
			$totalpart = 1/($total);
		}
		else
		{
			echo "Fehler: Keine Antworten vorhanden";
			$totalpart = 0;
		}
		#echo " anteil: ".$totalpart."<br/>";
		$amount = 0;
		$whole = 0;
		foreach($answers as $answer){
			if($answer['value'] != '-1'){
				for($i=0; $i<$answer['count']; $i++){
					$help = pow(($answer['value']-$average), 2);
					$whole = $whole + $help;
				}
			}
		}
		$result = round(sqrt($totalpart * $whole), 2);
		return $result;
	}
}
?>