<?php
/**
 * classes/ibit_EvaluationSummaryView.class.php
 *
 * @author    Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author    Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author    Ivn Marcos <ivan.marcos@gmx.net>
 * @author    Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package   IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version   1.3
 */

define( 'EVALUATION_SUMMARY_VIEW_BARS', 0 );
define( 'EVALUATION_SUMMARY_VIEW_PIE', 1 );

/**
 * Die Reprsentation einer Evaluationsauswertungssicht.
 *
 * Diese Klasse stellt Funktionen zum Auslesen, Speichern und ndern der Auswertungssichten einer Evaluationsgruppe oder -frage zur Verfgung.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.5
 * @todo Bei Update auf PHP5 kann die interne Referenz auf die Klasse selbst durch das Keyword self:: ersetzt werden.
 */
class ibit_EvaluationSummaryView
{
	/**
	 * Liest den Auswertungssichttypen einer Evaluationsgruppe fr User aus.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @return int Gibt den Sichttyp zurck.
	 * @static
	 * @uses ibit_EvaluationSummaryView::getAdminViewForQuestion()
	 */
	function getUserViewForGroup( $evaluation_id, $group_id )
	{
		return ibit_EvaluationSummaryView::getAdminViewForQuestion( $evaluation_id, $group_id, 0, '' );
	}

	/**
	 * Liest den Auswertungssichttypen einer Evaluationsgruppe fr einen bestimmten Admin aus.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param string $user_id Die Id des Admins (oder '' fr Usersicht)
	 * @return int Gibt den Sichttyp zurck.
	 * @static
	 * @uses ibit_EvaluationSummaryView::getAdminViewForQuestion()
	 */
	function getAdminViewForGroup( $evaluation_id, $group_id, $user_id )
	{
		return ibit_EvaluationSummaryView::getAdminViewForQuestion( $evaluation_id, $group_id, 0, $user_id );
	}

	/**
	 * Liest den Auswertungssichttypen einer Evaluationsfrage fr User aus.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param int $question_id Die Id der Frage (oder 0 fr Gruppensicht)
	 * @return int Gibt den Sichttyp zurck.
	 * @static
	 */
	function getUserViewForQuestion( $evaluation_id, $group_id, $question_id )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_load_view = 'SELECT view_type FROM ibit_evaluation_summary_views WHERE evaluation_id = ? AND evaluation_group_template_id = ? AND evaluation_question_template_id = ? LIMIT 0,1';

		$params = Array();
		array_push( $params, $evaluation_id );
		array_push( $params, $group_id );
		array_push( $params, $question_id );
		$result = $conn->Execute( $sql_load_view, $params );

		if ( !$result or $result->EOF )
		{
			return EVALUATION_SUMMARY_VIEW_BARS;
		}

		$view = $result->fields['view_type'];
		$result->Close();

		return $view;
	}

	/**
	 * Liest den Auswertungssichttypen einer Evaluationsfrage fr einen bestimmten Admin aus.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param int $question_id Die Id der Frage (oder 0 fr Gruppensicht)
	 * @param string $user_id Die Id des Admins (oder '' fr Usersicht)
	 * @return int Gibt den Sichttyp zurck.
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function getAdminViewForQuestion( $evaluation_id, $group_id, $question_id, $user_id )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_load_view = 'SELECT view_type FROM ibit_evaluation_summary_views WHERE evaluation_id = ? AND evaluation_group_template_id = ? AND evaluation_question_template_id = ? AND user_id = ? LIMIT 0,1';

		$params = Array();
		array_push( $params, $evaluation_id );
		array_push( $params, $group_id );
		array_push( $params, $question_id );
		array_push( $params, $user_id );
		$result = $conn->Execute( $sql_load_view, $params );

		if ( !$result or $result->EOF )
		{
			return EVALUATION_SUMMARY_VIEW_BARS;
		}

		$view = $result->fields['view_type'];
		$result->Close();

		return $view;
	}

	/**
	 * Speichert oder ndert den Auswertungssichttypen einer Evaluationsgruppe fr User.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param int $view Der Sichttyp
	 * @return boolean Gibt an, ob das Update erfolgreich war oder nicht.
	 * @static
	 * @uses ibit_EvaluationSummaryView::updateAdminViewForQuestion()
	 */
	function updateUserViewForGroup( $evaluation_id, $group_id, $view )
	{
		return ibit_EvaluationSummaryView::updateAdminViewForQuestion( $evaluation_id, $group_id, 0, '', $view );
	}

	/**
	 * Speichert oder ndert den Auswertungssichttypen einer Evaluationsgruppe fr einen bestimmten Admin.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param string $user_id Die Id des Admins
	 * @param int $view Der Sichttyp
	 * @return boolean Gibt an, ob das Update erfolgreich war oder nicht.
	 * @static
	 * @uses ibit_EvaluationSummaryView::updateAdminViewForQuestion()
	 */
	function updateAdminViewForGroup( $evaluation_id, $group_id, $user_id, $view )
	{
		return ibit_EvaluationSummaryView::updateAdminViewForQuestion( $evaluation_id, $group_id, 0, $user_id, $view );
	}

	/**
	 * Speichert oder ndert den Auswertungssichttypen einer Evaluationsfrage fr User.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param int $question_id Die Id der Frage
	 * @param int $view Der Sichttyp
	 * @return boolean Gibt an, ob das Update erfolgreich war oder nicht.
	 * @static
	 * @uses ibit_EvaluationSummaryView::updateAdminViewForQuestion()
	 */
	function updateUserViewForQuestion( $evaluation_id, $group_id, $question_id, $view )
	{
		return ibit_EvaluationSummaryView::updateAdminViewForQuestion( $evaluation_id, $group_id, $question_id, '', $view );
	}

	/**
	 * Speichert oder ndert den Auswertungssichttypen einer Evaluationsfrage fr einen bestimmten Admin.
	 * @param int $evaluation_id Die Id der Evaluation
	 * @param int $group_id Die Id der Gruppe
	 * @param int $question_id Die Id der Frage (oder 0 fr Gruppensicht)
	 * @param string $user_id Die Id des Admins (oder '' fr Usersicht)
	 * @param int $view Der Sichttyp
	 * @return boolean Gibt an, ob das Update erfolgreich war oder nicht.
	 * @static
	 * @uses ibit_DatabaseConnection
	 */
	function updateAdminViewForQuestion( $evaluation_id, $group_id, $question_id, $user_id, $view )
	{
		$conn = new ibit_DatabaseConnection( DISPLAY_SQL_ERRORS );

		$sql_update_view = 'REPLACE INTO ibit_evaluation_summary_views (evaluation_id, evaluation_group_template_id, evaluation_question_template_id, view_type, user_id) VALUES (?, ?, ?, ?, ?)';

		$params = Array();
		array_push( $params, $evaluation_id );
		array_push( $params, $group_id );
		array_push( $params, $question_id );
		array_push( $params, $view );
		array_push( $params, $user_id );
		$conn->Execute( $sql_update_view, $params );

		return $conn->Affected_Rows() > 0;
	}
}
?>