<?php
/**
 * ibit_EvaluationAdministrationPlugin.class.php
 *
 * Diese Datei enthlt die Hauptklasse des Plugins
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.7
 */

# Imports
require_once($GLOBALS['PLUGINS_PATH']. '/IBIT/ibit_EvaluationAdministrationPlugin/config.inc.php');

/**
 * Die Hauptklasse des Plugins
 *
 * Diese Klasse stellt die Hauptklasse des Plugins dar. Sie bernimmt dabei die Funktion eines FrontControllers, was bedeutet, dass alle
 * Anfragen an diese Klasse gesendet werden. Die Klasse selbst wird die Verarbeitung der Anfragen dann an andere Klassen weiterleiten.
 * Die Initialisierung des Plugins geschieht ebenfalls hier.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author     Ivn Marcos <ivan.marcos@gmx.net>
 * @package    IBIT_Evaluation
 * @subpackage Plugin
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.7
 */
class ibit_EvaluationAdministrationPlugin extends AbstractStudIPSystemPlugin
{
	/**
	 * Diese Variable enthlt eine Referenz auf die globale Templateklasse.
	 * @var object Globale Templateklasse
	 */
	var $templatelite;

	/**
	 * Konstruktor des Plugins.
	 * @uses PluginNavigation
	 * @todo Installationsskript einbauen (berprfen, ob vorhanden; wenn nicht - Beispielfragebogen erstellen, Rolle einfgen und Verzeichnis-Rechte setzen
	 */
	function ibit_EvaluationAdministrationPlugin()
	{
		parent::AbstractStudIPSystemPlugin();
		$this->setPluginiconname('images/icon.gif');

		# Templateklasse
		$this->templatelite =& $GLOBALS['templatelite'];

		# Navigationsreiter erzeugen
		$nav = new PluginNavigation();
		$nav->setDisplayname(_('Lehrveranstaltungs-Evaluationen Plugin'));
		$this->setNavigation($nav);

		# Root-Hinweis geben bei der Installation
		$admininfo = new AdminInfo();
		$admininfo->setMsg_activate(_('Dieses Plugin kann nur durch einen Root-Administrator aktiviert werden.'));
		$admininfo->setMsg_deactivate(_('Dieses Plugin kann nur durch einen Root-Administrator deaktiviert werden.'));
		$this->setPluginAdminInfo($admininfo);

		//TODO Installationsskript einbauen
		// berprfen ob vorhanden, wenn nicht, beispielfragebogen erstellen, rolle einfgen und verzeichnis-rechte setzen
	}

	/**
	 * Setzt den Pfad zum Plugin.
	 * @param string $path Pfad zum Plugin
	 */
	function setPluginpath( $path )
	{
		parent::setPluginpath( $path );
		$this->buildMenu();
	}

	/**
	 * Erstellt das Men des Plugins.
	 * @uses PluginNavigation
	 */
	function buildMenu() {
		$tab = new PluginNavigation();
		$tab->setDisplayname('Lehr-Evaluationen');

		$this->setNavigation( $tab );
	}

	/**
	 * Liefert den Namen des Plugins zurck.
	 * @return string Der Name des Plugins
	 */
	function getPluginname()
	{
		return _('Lehrveranstaltungs-Evaluationen Plugin');
	}

	/**
	 * Liefert die Navigation des Plugins zurck.
	 * @return mixed Navigation des Plugins
	 */
	function getNavigation()
	{
		return parent::getNavigation();
	}

	/**
	 * Stellt die Seite dar, indem der Header aus der Sitemap erzeugt wird und der Content in das Template eingefgt wird.
	 *
	 * @param array $sitemap Individuelle Sitemap des jeweiligen Benutzertyps (admin, dozent, student)
	 * @param string $content Inhalt der Seite
	 * @uses PluginEngine::getLink()
	 */
	function displayPage( $sitemap, $content )
	{
		# Header erzeugen
		$current_section = empty( $_REQUEST['section'] ) ? $sitemap[0]['subitems'][0]['section'] : $_REQUEST['section'];
		$current_function = empty( $_REQUEST['function'] ) ? $sitemap[0]['subitems'][0]['function'] : $_REQUEST['function'];

		$max_idx = count($sitemap)-1;
		$outer_tab_image = 2;

		$sites = Array();
		foreach ( $sitemap as $idx=>$item )
		{
			$section = Array( 'title'=>$item['title'], 'sites'=>Array() );
			$current = false;
			foreach ( $item['subitems'] as $subitem )
			{
				$params = Array( 'section'=>$subitem['section'] );
				if ( !empty( $subitem['function'] ) )
				{
					$params['function'] = $subitem['function'];
				}
				if ( !empty( $subitem['params'] ) )
				{
					$params = array_merge( $params, $subitem['params'] );
				}
				$link = PluginEngine::getLink( $this, $params );
				$site = Array( 'title'=>$subitem['title'], 'link'=>$link, 'hidden'=>!empty($subitem['hidden']) );
				if ( empty( $subitem['function'] ) and empty( $_REQUEST['function'] ) )
				{
					$current = ( $site['current'] = ( $subitem['section'] == $current_section ) ) || $current;
				}
				elseif ( !empty( $subitem['function'] ) )
				{
					$current = ( $site['current'] = ( $subitem['section'] == $current_section and $subitem['function'] == $current_function ) ) || $current;
				}
				array_push( $section['sites'], $site );
			}

			$tab_image = 1;
			if ( $section['current'] = $current )
			{
				if ( $idx == 0 )
				{
					$outer_tab_image = 1;
				}
				$tab_image = 2;
			}

			$section[ 'tab_image' ] = ( $idx == $max_idx ) ? 4 : $tab_image;

			array_push( $sites, $section );
		}

		$this->templatelite->assign( 'tab_image', $outer_tab_image );
		$this->templatelite->assign( 'sites', $sites );

		# Content einfgen
		$this->templatelite->assign( 'page_content', $content );

		# Seite anzeigen
		$this->templatelite->display( 'common.header.tpl' );
	}

	/**
	 * Hauptanzeigefunktion des Plugins.
	 *
	 * ber diese Funktion werden alle Seiten des Plugins verwaltet und ausgegeben.
	 * @uses ibit_Action_Admin
	 * @uses ibit_Action_Teacher
	 * @uses ibit_Action_User
	 */
	function show()
	{
		# debug infos
		if(!empty($_REQUEST['debug']) && $_REQUEST['debug'] == 'phpinfo')
		{
			phpinfo();
			exit;
		}

		$section = empty( $_REQUEST['section'] ) ? '' : trim( $_REQUEST['section'] );

		if ( !empty( $_REQUEST['confirm'] ) and $_REQUEST['confirm'] == 'this' )
		{
			$params = Array();
			if ( !empty( $section ) )
			{
				$params['section'] = $section;
			}

			$this->templatelite->assign( 'confirm_message', urldecode($_REQUEST['message']) );
			$this->templatelite->assign( 'confirm_yes', urldecode( $_REQUEST['yes'] ) );
			$this->templatelite->assign( 'confirm_no', urldecode( $_REQUEST['no'] ) );
			$this->templatelite->display( 'common.confirm.tpl' );
			return;
		}

		$this->templatelite->assign('link_get_confirmation', PluginEngine::getLink( $this, Array( 'section'=>$section, 'confirm'=>'this' ) ) );

		# Falls Druckansicht, nichts anzeigen von studip
		if(!empty($_GET['print']) && $_GET['print'] == "yes")
		{
			ob_end_clean();
		}
		ob_start();


		$this->templatelite->assign( 'link_main', PluginEngine::getLink( $this ) );
		$this->templatelite->assign( 'link_base', PluginEngine::getLink( $this, Array( 'section'=>$section ) ) );

		$user = $this->getUser();
		$permission	= $user->getPermission();

		# Prfen, ob der User die Rolle 'eval_admin' hat oder Fakulttsadmin ist
		$eval_admin = false;
		$roles = $user->getAssignedRoles();
		foreach ( $roles as $role )
		{
			if ( $role->rolename == 'eval_admin' )
			{
				$eval_admin = true;
			}
			/*if ( $role->rolename == 'fak1_admin' )
			{
				$fak1_admin = true;
				$fak_admin = 1;
			}
			if ( $role->rolename == 'fak2_admin' )
			{
				$fak2_admin = true;
				$fak_admin = 2;
			}
			if ( $role->rolename == 'fak3_admin' )
			{
				$fak3_admin = true;
				$fak_admin = 3;
			}
			if ( $role->rolename == 'fak4_admin' )
			{
				$fak4_admin = true;
				$fak_admin = 4;
			}
			if ( $role->rolename == 'fak5_admin' )
			{
				$fak5_admin = true;
				$fak_admin = 5;
			}*/
		}
		# Fakulttsadmin ist eingeloggt

		# Root ist eingeloggt
		if ( $permission->hasRootPermission() or $eval_admin )
		{
			$sitemap = $GLOBALS['evaluation_menu_admin'];
			$this->templatelite->assign( 'admin_view', true );
			new ibit_Action_Handler_Admin( $this, $user->userid );
		}
		# Admin ist eingeloggt
		elseif( $permission->hasAdminPermission())
		{
			$sitemap = $GLOBALS['evaluation_menu_fakadmin'];
			$this->templatelite->assign( 'fakadmin_view', true );
			new ibit_Action_Handler_FakAdmin( $this, $user->userid, 1 ); //TODO: wie den einzelnen admins eine fakultt zuweisen? erstmal bekommen alle die 1...
		}
		# Dozent ist eingeloggt
		elseif( $permission->hasTeacherPermission() )
		{
			$sitemap = $GLOBALS['evaluation_menu_dozent'];
			$this->templatelite->assign( 'teacher_view', true );
			new ibit_Action_Handler_Teacher( $this, $user->userid );
		}
		# Student ist eingeloggt
		else
		{
			$sitemap = $GLOBALS['evaluation_menu_student'];
			new ibit_Action_Handler_User( $this, $user->userid );
		}

		# Falls keine Druckansicht
		if(empty($_GET['print']))
		{
			$content = ob_get_contents();
			ob_end_clean();
			$this->displayPage( $sitemap, $content );
		}

	}

	# Kompatiblitt zu Pluginschnittstellennderungen
	function actionShow()
	{
			return $this->show();
	}
}
?>